import palette from '../../_data/colors/palette.json';

export default {
	800: palette[ 'gray-anthracite' ],
	700: palette[ 'gray-metalise' ],
	600: palette[ 'gray-napoleon' ],
	500: palette[ 'gray-abbey' ],
	400: palette[ 'gray-stone-hearth' ],
	300: palette[ 'gray-silver-filigree' ],
	200: palette[ 'gray-brainstem' ],
	100: palette[ 'gray-yin-bai-silver' ],
};
