<!-- wp:template-part {"slug":"header","tagName":"header"} /-->

<!-- wp:group {"tagName":"main","className":"site-content page-cover-title"} -->
<main id="primary" class="wp-block-group site-content page-cover-title">

	<!-- wp:pattern {"slug":"alara/cover-title-featured-image"} /-->

	<!-- wp:post-content {"layout":{"inherit":true}} /-->

	<!-- wp:group {"layout":{"inherit":true}} -->
	<div class="wp-block-group">
		<!-- wp:post-comments {"className":"is-style-hide-nocomments"} /-->
	</div>
	<!-- /wp:group -->

</main>
<!-- /wp:group -->

<!-- wp:template-part {"slug":"footer","tagName":"footer"} /-->