import type from '../../_data/typography/typography.json';

export default {
	2: type[ 'line-height-2' ],
	flat: type[ 'line-height-flat' ],
	base: type[ 'line-height-base' ],
	sm: type[ 'line-height-sm' ],
	lg: type[ 'line-height-lg' ],
};
