<?php
return array(
			'title'         => __( 'Who We Are', 'alara' ),
			'categories'    => array( 'alara-about' ),
			'keywords'		=> array( 'about', 'agency', 'column' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:group {"align":"full","style":{"spacing":{"padding":{"top":"6em","bottom":"6em"}}},"backgroundColor":"foreground","layout":{"inherit":true}} -->
<div class="wp-block-group alignfull has-foreground-background-color has-background" style="padding-top:6em;padding-bottom:6em"><!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column {"width":"33.33%"} -->
<div class="wp-block-column" style="flex-basis:33.33%"></div>
<!-- /wp:column -->

<!-- wp:column {"width":"66.66%"} -->
<div class="wp-block-column" style="flex-basis:66.66%"><!-- wp:paragraph {"textColor":"background"} -->
<p class="has-background-color has-text-color">Connecting you and your audience for 15+ years through powerful design.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:paragraph {"textColor":"background"} -->
<p class="has-background-color has-text-color">We are a forward thinking agency with the resources and knowhow required to deliver any project of any size and scope.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->

<!-- wp:paragraph {"align":"center","textColor":"background","fontSize":"colossal"} -->
<p class="has-text-align-center has-background-color has-text-color has-colossal-font-size"><strong>WHO WE ARE</strong></p>
<!-- /wp:paragraph -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column {"textColor":"background"} -->
<div class="wp-block-column has-background-color has-text-color"><!-- wp:paragraph -->
<p>We are multiple award-winning and are proud to partner with some of world\'s best known and influential brands.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div>
<!-- /wp:group -->',
);
