.editor-styles-wrapper :where(:not(.is-layout-flex,.is-layout-grid))>.wp-block{
  margin-left:auto;
  margin-right:auto;
}

html :where(.editor-styles-wrapper){
  padding:8px;
}
html :where(.editor-styles-wrapper) .block-editor-block-list__layout.is-root-container>.wp-block[data-align=full]{
  margin-left:-8px;
  margin-right:-8px;
}

html :where(.wp-block){
  margin-bottom:28px;
  margin-top:28px;
  max-width:840px;
}
html :where(.wp-block)[data-align=wide]{
  max-width:1100px;
}
html :where(.wp-block)[data-align=full]{
  max-width:none;
}
html :where(.wp-block)[data-align=left],html :where(.wp-block)[data-align=right]{
  height:0;
  width:100%;
}
html :where(.wp-block)[data-align=left]:before,html :where(.wp-block)[data-align=right]:before{
  content:none;
}
html :where(.wp-block)[data-align=left]>*{
  float:left;
  margin-right:2em;
}
html :where(.wp-block)[data-align=right]>*{
  float:right;
  margin-left:2em;
}
html :where(.wp-block)[data-align=full],html :where(.wp-block)[data-align=wide]{
  clear:both;
}

.wp-block-group>[data-align=full]{
  margin-left:auto;
  margin-right:auto;
}

.wp-block-group.has-background>[data-align=full]{
  margin-left:-30px;
  width:calc(100% + 60px);
}
[data-align=full] .wp-block-group>.wp-block{
  padding-left:14px;
  padding-right:14px;
}
@media (min-width:600px){
  [data-align=full] .wp-block-group>.wp-block{
    padding-left:0;
    padding-right:0;
  }
}
[data-align=full] .wp-block-group>[data-align=full]{
  left:0;
  max-width:none;
  padding-left:0;
  padding-right:0;
  width:100%;
}
[data-align=full] .wp-block-group.has-background>[data-align=full]{
  width:calc(100% + 60px);
}