.customize-control-zita-buttonset .buttonset { display: inline-block; border: 1px solid #ccc; }
.customize-control-zita-buttonset .buttonset .switch-label {float: left;
    background-color: #f5f5f5;
    color: #555;
    border-right: 1px solid rgba(0, 0, 0, 0.2);
    padding: 14px 10px;
    margin: 0;
    font-size: 12px;
    font-weight: 600;
    line-height: 1;
    letter-spacing: 1px;
    text-transform: uppercase;}
.customize-control-zita-buttonset .buttonset .switch-label:last-child { border-right: none; }
.customize-control-zita-buttonset .buttonset .switch-input { display: none; }
.customize-control-zita-buttonset .buttonset .switch-input:checked + .switch-label { background-color:#006799; color: #fff; }