import React from 'react'
import styles from './NoResultsFound.module.scss'

const NoResultsFound = () => (
  <div className={styles.noResults}>Sorry no results found.</div>
)

export default NoResultsFound
