<?php
/**
 * Exception for errors from the Text_Diff package.
 *
 * {@internal This is a WP native addition to the external Text_Diff package.}
 *
 * @package WordPress
 * @subpackage Text_Diff
 */

class Text_Exception extends Exception {}
