.noResults {
  width: 100%;
  height: 100px;
  padding: 20px;
  border-radius: 4px;
  margin: 0 auto;
  background: #fff;
  display: flex;
  justify-content: center;
  align-items: center;
  box-shadow: 0 2px 2px rgba(0, 0, 0, 0.1);
}
