<?php
return array(
			'title'         => __( 'Reviews 3', 'alara' ),
			'categories'    => array( 'alara-reviews' ),
			'keywords'		=> array( 'feedback', 'testimonial', 'column', 'cover' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:columns {"verticalAlignment":null,"isStackedOnMobile":false,"className":"is-style-zero-gap"} -->
<div class="wp-block-columns is-not-stacked-on-mobile is-style-zero-gap"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:cover {"url":"' . alara_pattern_content( 'image-man-2' ) . '","dimRatio":50,"overlayColor":"secondary","contentPosition":"bottom center"} -->
<div class="wp-block-cover has-custom-content-position is-position-bottom-center"><span aria-hidden="true" class="has-secondary-background-color wp-block-cover__gradient-background has-background-dim"></span><img class="wp-block-cover__image-background" alt="" src="' . alara_pattern_content( 'image-man-2' ) . '" data-object-fit="cover"/><div class="wp-block-cover__inner-container"><!-- wp:paragraph {"align":"center","textColor":"foreground","fontSize":"large"} -->
<p class="has-text-align-center has-foreground-color has-text-color has-large-font-size">"Awesome, simply awesome!"</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"textColor":"foreground"} -->
<p class="has-foreground-color has-text-color">★★★★★</p>
<!-- /wp:paragraph --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:cover {"overlayColor":"primary","contentPosition":"bottom center","isDark":false,"style":{"spacing":{"padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"}}}} -->
<div class="wp-block-cover is-light has-custom-content-position is-position-bottom-center" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><span aria-hidden="true" class="has-primary-background-color has-background-dim-100 wp-block-cover__gradient-background has-background-dim"></span><div class="wp-block-cover__inner-container"><!-- wp:group {"style":{"spacing":{"padding":{"top":"1em","right":"1em","bottom":"1em","left":"1em"}}}} -->
<div class="wp-block-group" style="padding-top:1em;padding-right:1em;padding-bottom:1em;padding-left:1em"><!-- wp:paragraph {"textColor":"background","fontSize":"large"} -->
<p class="has-background-color has-text-color has-large-font-size"><strong><em><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-octonary-color">What our</mark></em> customers say</strong></p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":32} -->
<div style="height:32px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group -->

<!-- wp:columns {"isStackedOnMobile":false,"className":"is-style-zero-gap"} -->
<div class="wp-block-columns is-not-stacked-on-mobile is-style-zero-gap"><!-- wp:column {"style":{"spacing":{"padding":{"top":"1em","right":"1em","bottom":"1em","left":"1em"}}},"backgroundColor":"foreground"} -->
<div class="wp-block-column has-foreground-background-color has-background" style="padding-top:1em;padding-right:1em;padding-bottom:1em;padding-left:1em"><!-- wp:paragraph {"textColor":"background"} -->
<p class="has-background-color has-text-color">Makes this service so much easier to use, and our clients love it too.</p>
<!-- /wp:paragraph --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"1em","right":"1em","bottom":"1em","left":"1em"}}},"backgroundColor":"secondary"} -->
<div class="wp-block-column has-secondary-background-color has-background" style="padding-top:1em;padding-right:1em;padding-bottom:1em;padding-left:1em"><!-- wp:spacer {"height":48} -->
<div style="height:48px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:paragraph {"className":"is-style-links-plain"} -->
<p class="is-style-links-plain"><a href="#">More testimonials →</a></p>
<!-- /wp:paragraph --></div>
<!-- /wp:column --></div>
<!-- /wp:columns --></div></div>
<!-- /wp:cover --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
