<?php
return array(
	'title'			=> __( 'Pricing Table 5', 'alara' ),
	'categories'	=> array( 'alara-pricing-tables' ),
	'keywords'		=> array( 'column' ),
	'viewportWidth'	=> 1280,
	'content'		=> '<!-- wp:columns {"align":""} -->
<div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"bottom":"0px","top":"0px","right":"0px","left":"0px"}}},"textColor":"black"} -->
<div class="wp-block-column has-black-color has-text-color" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:group {"style":{"spacing":{"padding":{"top":"20px","right":"20px","bottom":"20px","left":"20px"}},"border":{"radius":"10px"}},"borderColor":"tertiary","backgroundColor":"tertiary"} -->
<div class="wp-block-group has-border-color has-tertiary-border-color has-tertiary-background-color has-background" style="border-radius:10px;padding-top:20px;padding-right:20px;padding-bottom:20px;padding-left:20px"><!-- wp:group {"style":{"border":{"radius":"8px"},"spacing":{"padding":{"top":"30px","right":"20px","bottom":"50px","left":"20px"}}},"backgroundColor":"octonary"} -->
<div class="wp-block-group has-octonary-background-color has-background" style="border-radius:8px;padding-top:30px;padding-right:20px;padding-bottom:50px;padding-left:20px"><!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size" id="tier-1"><strong>Tier 1</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$9</strong> <sub><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color">/ month</mark></sub></p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:list {"className":"is-style-circle","fontSize":"small"} -->
<ul class="is-style-circle has-small-font-size">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"black","textColor":"white","width":100,"className":"is-style-fill","fontSize":"small"} -->
<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size is-style-fill has-small-font-size"><a class="wp-block-button__link has-white-color has-black-background-color has-text-color has-background">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"}}},"textColor":"black"} -->
<div class="wp-block-column has-black-color has-text-color" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:group {"style":{"spacing":{"padding":{"top":"20px","right":"20px","bottom":"20px","left":"20px"}},"border":{"radius":"10px"}},"backgroundColor":"quaternary"} -->
<div class="wp-block-group has-quaternary-background-color has-background" style="border-radius:10px;padding-top:20px;padding-right:20px;padding-bottom:20px;padding-left:20px"><!-- wp:group {"style":{"border":{"radius":"8px"},"spacing":{"padding":{"top":"30px","right":"20px","bottom":"50px","left":"20px"}}},"backgroundColor":"octonary"} -->
<div class="wp-block-group has-octonary-background-color has-background" style="border-radius:8px;padding-top:30px;padding-right:20px;padding-bottom:50px;padding-left:20px"><!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size" id="tier-1"><strong>Tier 2</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$14</strong> <sub><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color">/ month</mark></sub></p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:list {"className":"is-style-circle","fontSize":"small"} -->
<ul class="is-style-circle has-small-font-size">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"black","textColor":"white","width":100,"className":"is-style-fill","fontSize":"small"} -->
<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size is-style-fill has-small-font-size"><a class="wp-block-button__link has-white-color has-black-background-color has-text-color has-background">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"top":"0px","right":"0px","bottom":"0px","left":"0px"}}},"textColor":"black"} -->
<div class="wp-block-column has-black-color has-text-color" style="padding-top:0px;padding-right:0px;padding-bottom:0px;padding-left:0px"><!-- wp:group {"style":{"spacing":{"padding":{"top":"20px","right":"20px","bottom":"20px","left":"20px"}},"border":{"radius":"10px"}},"backgroundColor":"quinary"} -->
<div class="wp-block-group has-quinary-background-color has-background" style="border-radius:10px;padding-top:20px;padding-right:20px;padding-bottom:20px;padding-left:20px"><!-- wp:group {"style":{"spacing":{"padding":{"top":"30px","right":"20px","bottom":"50px","left":"20px"}},"border":{"radius":"8px"}},"backgroundColor":"octonary"} -->
<div class="wp-block-group has-octonary-background-color has-background" style="border-radius:8px;padding-top:30px;padding-right:20px;padding-bottom:50px;padding-left:20px"><!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size" id="tier-1"><strong>Tier 3 </strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$19</strong> <sub><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-foreground-color">/ month</mark></sub></p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:list {"className":"is-style-circle","fontSize":"small"} -->
<ul class="is-style-circle has-small-font-size">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"black","textColor":"white","width":100,"className":"is-style-fill","fontSize":"small"} -->
<div class="wp-block-button has-custom-width wp-block-button__width-100 has-custom-font-size is-style-fill has-small-font-size"><a class="wp-block-button__link has-white-color has-black-background-color has-text-color has-background">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:group --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
