:root{
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
  --wp-editor-canvas-background:#ddd;
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 160.5;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}
.admin-ui-page{
  background-color:#fff;
  color:#2f2f2f;
  container:admin-ui-page/inline-size;
  display:flex;
  flex-flow:column;
  height:100%;
  position:relative;
  z-index:1;
}

@media not (prefers-reduced-motion){
  .admin-ui-page{
    transition:width .2s ease-out;
  }
}
.admin-ui-page__header{
  background:#fff;
  border-bottom:1px solid #f0f0f0;
  padding:16px 48px;
  position:sticky;
  top:0;
}

@container (max-width: 430px){
  .admin-ui-page__header{
    padding:16px 24px;
  }
}
.admin-ui-page__header-subtitle{
  color:#757575;
  font-family:-apple-system,"system-ui",Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:13px;
  font-weight:400;
  line-height:20px;
  margin:0;
  padding-block-end:8px;
}

.admin-ui-page__content{
  display:flex;
  flex-direction:column;
  flex-grow:1;
  overflow:auto;
}

.admin-ui-page__content.has-padding{
  padding:16px 20px;
}

@container (max-width: 430px){
  .admin-ui-page__content.has-padding{
    padding:16px 24px;
  }
}
.show-icon-labels .admin-ui-page__header-actions .components-button.has-icon{
  padding:0 8px;
  width:auto;
}

.show-icon-labels .admin-ui-page__header-actions .components-button.has-icon svg{
  display:none;
}

.show-icon-labels .admin-ui-page__header-actions .components-button.has-icon:after{
  content:attr(aria-label);
  font-size:12px;
}

.edit-post-fullscreen-mode-close__view-mode-toggle{
  height:64px;
  right:0;
  top:0;
  width:64px;
  z-index:100;
}
.edit-post-fullscreen-mode-close__view-mode-toggle .components-button{
  align-items:center;
  border-radius:0;
  color:#fff;
  display:flex;
  height:100%;
  justify-content:center;
  overflow:hidden;
  padding:0;
  width:100%;
}
.edit-post-fullscreen-mode-close__view-mode-toggle .components-button:active,.edit-post-fullscreen-mode-close__view-mode-toggle .components-button:hover{
  color:#fff;
}
.edit-post-fullscreen-mode-close__view-mode-toggle .components-button:focus{
  box-shadow:none;
}
.edit-post-fullscreen-mode-close__view-mode-toggle .edit-post-fullscreen-mode-close__view-mode-toggle-icon img,.edit-post-fullscreen-mode-close__view-mode-toggle .edit-post-fullscreen-mode-close__view-mode-toggle-icon svg{
  background:#1e1e1e;
  display:block;
}

.edit-post-fullscreen-mode-close-site-icon__icon{
  fill:currentColor;
  height:100%;
  padding:12px;
  width:100%;
}

.edit-post-fullscreen-mode-close-site-icon__image{
  aspect-ratio:1/1;
  background:#333;
  height:100%;
  object-fit:cover;
  width:100%;
}

.edit-post-fullscreen-mode-close.components-button:focus{
  position:relative;
}
.edit-post-fullscreen-mode-close.components-button:focus:before{
  bottom:0;
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color), inset 0 0 0 calc(1px + var(--wp-admin-border-width-focus)) #fff;
  content:"";
  display:block;
  left:0;
  position:absolute;
  right:0;
  top:0;
  z-index:1;
}

.edit-post-fullscreen-mode-close__back-icon{
  align-items:center;
  background-color:#ccc;
  display:flex;
  height:64px;
  justify-content:center;
  pointer-events:none;
  position:absolute;
  right:0;
  top:0;
  width:64px;
}
.edit-post-fullscreen-mode-close__back-icon svg{
  fill:currentColor;
}
.edit-post-fullscreen-mode-close__back-icon.has-site-icon{
  backdrop-filter:saturate(180%) blur(15px);
  background-color:#fff9;
}
.show-icon-labels .editor-header .edit-post-fullscreen-mode-close.has-icon{
  width:64px;
}
.show-icon-labels .editor-header .edit-post-fullscreen-mode-close.has-icon svg{
  display:block;
}
.show-icon-labels .editor-header .edit-post-fullscreen-mode-close.has-icon:after{
  content:none;
}

.edit-post-meta-boxes-main{
  background-color:#fff;
  display:flex;
  filter:drop-shadow(0 -1px rgba(0, 0, 0, .133));
  flex-direction:column;
  outline:1px solid #0000;
  overflow:hidden;
  padding-block-start:32px;
}

.edit-post-meta-boxes-main__presenter{
  box-shadow:0 1px #ddd;
  display:flex;
  height:32px;
  inset:0 0 auto;
  outline:1px solid #0000;
  position:relative;
  z-index:10000;
}
.edit-post-meta-boxes-main__presenter>button{
  appearance:none;
  background-color:initial;
  border:none;
  outline:none;
  padding:0;
}
.edit-post-meta-boxes-main__presenter>button[aria-expanded]{
  align-items:center;
  cursor:pointer;
  display:flex;
  justify-content:space-between;
  padding-inline:24px 12px;
  width:100%;
}
.edit-post-meta-boxes-main__presenter>button[aria-expanded]:is(:hover,:focus-visible){
  color:var(--wp-admin-theme-color);
}
.edit-post-meta-boxes-main__presenter>button[aria-expanded]:focus-visible:after{
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  content:"";
  inset:var(--wp-admin-border-width-focus);
  outline:2px solid #0000;
  position:absolute;
}
.edit-post-meta-boxes-main__presenter>button[aria-expanded]>svg{
  fill:currentColor;
}
.edit-post-meta-boxes-main__presenter button[role=separator]{
  cursor:row-resize;
  inset:0;
  margin:auto;
  position:absolute;
  width:64px;
}
.edit-post-meta-boxes-main__presenter button[role=separator]:before{
  background-color:#ddd;
  border-radius:2px;
  content:"";
  height:4px;
  inset-block:calc(50% - 2px) auto;
  outline:2px solid #0000;
  outline-offset:-2px;
  position:absolute;
  transform:translateX(50%);
  width:inherit;
}
@media not (prefers-reduced-motion){
  .edit-post-meta-boxes-main__presenter button[role=separator]:before{
    transition:width .3s ease-out;
  }
}
.edit-post-meta-boxes-main__presenter button[role=separator]:is(:hover,:focus-visible):before{
  background-color:var(--wp-admin-theme-color);
  width:80px;
}

@media (pointer:coarse){
  .edit-post-meta-boxes-main{
    padding-block-start:36px;
  }
  .edit-post-meta-boxes-main__presenter{
    height:36px;
  }
}
.edit-post-meta-boxes-main .edit-post-meta-boxes-main__liner{
  overflow:auto;
}
.edit-post-meta-boxes-main__liner{
  isolation:isolate;
}
.is-resizing.edit-post-meta-boxes-main .edit-post-meta-boxes-main__liner{
  display:unset;
}

.edit-post-layout__metaboxes{
  clear:both;
}

.has-metaboxes .interface-interface-skeleton__content:has(.edit-post-meta-boxes-main) .editor-visual-editor{
  flex-basis:0%;
  flex-shrink:1;
}

.has-metaboxes .editor-visual-editor.is-iframed{
  isolation:isolate;
}

.components-editor-notices__snackbar{
  bottom:24px;
  left:0;
  padding-left:24px;
  padding-right:24px;
  position:fixed;
}

.edit-post-layout .components-editor-notices__snackbar{
  right:0;
}
@media (min-width:783px){
  .edit-post-layout .components-editor-notices__snackbar{
    right:160px;
  }
}
@media (min-width:783px){
  .auto-fold .edit-post-layout .components-editor-notices__snackbar{
    right:36px;
  }
}
@media (min-width:961px){
  .auto-fold .edit-post-layout .components-editor-notices__snackbar{
    right:160px;
  }
}
.folded .edit-post-layout .components-editor-notices__snackbar{
  right:0;
}
@media (min-width:783px){
  .folded .edit-post-layout .components-editor-notices__snackbar{
    right:36px;
  }
}

body.is-fullscreen-mode .edit-post-layout .components-editor-notices__snackbar{
  right:0 !important;
}

.edit-post-meta-boxes-area{
  position:relative;
}
.edit-post-meta-boxes-area .inside,.edit-post-meta-boxes-area__container{
  box-sizing:initial;
}
.edit-post-meta-boxes-area input,.edit-post-meta-boxes-area textarea{
  box-sizing:border-box;
}
.edit-post-meta-boxes-area .postbox-header{
  border-bottom:0;
  border-top:1px solid #ddd;
}
.edit-post-meta-boxes-area #poststuff{
  margin:0 auto;
  min-width:auto;
  padding-top:0;
}
.edit-post-meta-boxes-area #poststuff .stuffbox>h3,.edit-post-meta-boxes-area #poststuff h2.hndle,.edit-post-meta-boxes-area #poststuff h3.hndle{
  box-sizing:border-box;
  color:inherit;
  font-weight:600;
  outline:none;
  padding:0 24px;
  position:relative;
  width:100%;
}
.edit-post-meta-boxes-area .postbox{
  border:0;
  color:inherit;
  margin-bottom:0;
}
.edit-post-meta-boxes-area .postbox>.inside{
  color:inherit;
  margin:0;
  padding:0 24px 24px;
}
.edit-post-meta-boxes-area .postbox .handlediv{
  height:44px;
  width:44px;
}
.edit-post-meta-boxes-area.is-loading:before{
  background:#0000;
  bottom:0;
  content:"";
  left:0;
  position:absolute;
  right:0;
  top:0;
  z-index:1;
}
.edit-post-meta-boxes-area .components-spinner{
  left:20px;
  position:absolute;
  top:10px;
  z-index:5;
}
.edit-post-meta-boxes-area .is-hidden{
  display:none;
}
.edit-post-meta-boxes-area .metabox-location-side .postbox input[type=checkbox]{
  border:1px solid #757575;
}
.edit-post-meta-boxes-area .metabox-location-side .postbox input[type=checkbox]:checked{
  background:#fff;
  border-color:#757575;
}
.edit-post-meta-boxes-area .metabox-location-side .postbox input[type=checkbox]:before{
  margin:-3px -4px;
}

.edit-post-meta-boxes-area__clear{
  clear:both;
}

.edit-post-welcome-guide,.edit-template-welcome-guide{
  width:312px;
}
.edit-post-welcome-guide__image,.edit-template-welcome-guide__image{
  background:#00a0d2;
  margin:0 0 16px;
}
.edit-post-welcome-guide__image>img,.edit-template-welcome-guide__image>img{
  display:block;
  max-width:100%;
  object-fit:cover;
}
.edit-post-welcome-guide__heading,.edit-template-welcome-guide__heading{
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:24px;
  line-height:1.4;
  margin:16px 0;
  padding:0 32px;
}
.edit-post-welcome-guide__text,.edit-template-welcome-guide__text{
  font-size:13px;
  line-height:1.4;
  margin:0 0 24px;
  padding:0 32px;
}
.edit-post-welcome-guide__inserter-icon,.edit-template-welcome-guide__inserter-icon{
  margin:0 4px;
  vertical-align:text-top;
}

.edit-template-welcome-guide .components-button svg{
  fill:#fff;
}

body.js.block-editor-page{
  background:#fff;
}
body.js.block-editor-page #wpcontent{
  padding-right:0;
}
body.js.block-editor-page #wpbody-content{
  padding-bottom:0;
}
body.js.block-editor-page #wpbody-content>div:not(.block-editor):not(#screen-meta),body.js.block-editor-page #wpfooter{
  display:none;
}
body.js.block-editor-page .a11y-speak-region{
  right:-1px;
  top:-1px;
}
body.js.block-editor-page ul#adminmenu a.wp-has-current-submenu:after,body.js.block-editor-page ul#adminmenu>li.current>a.current:after{
  border-left-color:#fff;
}
body.js.block-editor-page .media-frame select.attachment-filters:last-of-type{
  max-width:100%;
  width:auto;
}

.block-editor-page #wpwrap{
  overflow-y:auto;
}
@media (min-width:782px){
  .block-editor-page #wpwrap{
    overflow-y:initial;
  }
}

.edit-post-visual-editor.is-iframed{
  box-sizing:border-box;
}
.edit-post-visual-editor.is-iframed *,.edit-post-visual-editor.is-iframed :after,.edit-post-visual-editor.is-iframed :before{
  box-sizing:inherit;
}

@media (min-width:600px){
  .block-editor__container{
    bottom:0;
    left:0;
    min-height:calc(100vh - 46px);
    position:absolute;
    right:0;
    top:0;
  }
}
@media (min-width:782px){
  .block-editor__container{
    min-height:calc(100vh - 32px);
  }
  body.is-fullscreen-mode .block-editor__container{
    min-height:100vh;
  }
}
.block-editor__container img{
  height:auto;
  max-width:100%;
}

body.admin-color-light{
  --wp-admin-theme-color:#0085ba;
  --wp-admin-theme-color--rgb:0, 133, 186;
  --wp-admin-theme-color-darker-10:#0073a1;
  --wp-admin-theme-color-darker-10--rgb:0, 114.7661290323, 160.5;
  --wp-admin-theme-color-darker-20:#006187;
  --wp-admin-theme-color-darker-20--rgb:0, 96.5322580645, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-light{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-modern{
  --wp-admin-theme-color:#3858e9;
  --wp-admin-theme-color--rgb:56, 88, 233;
  --wp-admin-theme-color-darker-10:#2145e6;
  --wp-admin-theme-color-darker-10--rgb:33.0384615385, 68.7307692308, 230.4615384615;
  --wp-admin-theme-color-darker-20:#183ad6;
  --wp-admin-theme-color-darker-20--rgb:23.6923076923, 58.1538461538, 214.3076923077;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-modern{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-blue{
  --wp-admin-theme-color:#096484;
  --wp-admin-theme-color--rgb:9, 100, 132;
  --wp-admin-theme-color-darker-10:#07526c;
  --wp-admin-theme-color-darker-10--rgb:7.3723404255, 81.914893617, 108.1276595745;
  --wp-admin-theme-color-darker-20:#064054;
  --wp-admin-theme-color-darker-20--rgb:5.7446808511, 63.829787234, 84.2553191489;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-blue{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-coffee{
  --wp-admin-theme-color:#46403c;
  --wp-admin-theme-color--rgb:70, 64, 60;
  --wp-admin-theme-color-darker-10:#383330;
  --wp-admin-theme-color-darker-10--rgb:56.2692307692, 51.4461538462, 48.2307692308;
  --wp-admin-theme-color-darker-20:#2b2724;
  --wp-admin-theme-color-darker-20--rgb:42.5384615385, 38.8923076923, 36.4615384615;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-coffee{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ectoplasm{
  --wp-admin-theme-color:#523f6d;
  --wp-admin-theme-color--rgb:82, 63, 109;
  --wp-admin-theme-color-darker-10:#46365d;
  --wp-admin-theme-color-darker-10--rgb:69.8430232558, 53.6598837209, 92.8401162791;
  --wp-admin-theme-color-darker-20:#3a2c4d;
  --wp-admin-theme-color-darker-20--rgb:57.6860465116, 44.3197674419, 76.6802325581;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ectoplasm{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-midnight{
  --wp-admin-theme-color:#e14d43;
  --wp-admin-theme-color--rgb:225, 77, 67;
  --wp-admin-theme-color-darker-10:#dd382d;
  --wp-admin-theme-color-darker-10--rgb:221.4908256881, 56.1788990826, 45.0091743119;
  --wp-admin-theme-color-darker-20:#d02c21;
  --wp-admin-theme-color-darker-20--rgb:207.8348623853, 44.2201834862, 33.1651376147;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-midnight{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ocean{
  --wp-admin-theme-color:#627c83;
  --wp-admin-theme-color--rgb:98, 124, 131;
  --wp-admin-theme-color-darker-10:#576e74;
  --wp-admin-theme-color-darker-10--rgb:87.0873362445, 110.192139738, 116.4126637555;
  --wp-admin-theme-color-darker-20:#4c6066;
  --wp-admin-theme-color-darker-20--rgb:76.1746724891, 96.384279476, 101.8253275109;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ocean{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-sunrise{
  --wp-admin-theme-color:#dd823b;
  --wp-admin-theme-color--rgb:221, 130, 59;
  --wp-admin-theme-color-darker-10:#d97426;
  --wp-admin-theme-color-darker-10--rgb:216.8782608696, 116.1847826087, 37.6217391304;
  --wp-admin-theme-color-darker-20:#c36922;
  --wp-admin-theme-color-darker-20--rgb:195.147826087, 104.5434782609, 33.852173913;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-sunrise{
    --wp-admin-border-width-focus:1.5px;
  }
}