/*
Theme Name: Richmond
Theme URI: https://uxlthemes.com/alara-design-variations/
Author: UXL Themes
Author URI: https://uxlthemes.com/
Description: Richmond is a design variation of the Alara theme, with a nature inspired earthy color palette.
Requires at least: 5.9
Tested up to: 5.9
Requires PHP: 5.6
Version: 1.0
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Template: alara
Text Domain: richmond
Tags: full-site-editing, block-patterns, block-styles, grid-layout, wide-blocks, custom-background, custom-colors, custom-header, custom-menu, custom-logo, editor-style, featured-images, template-editing, blog, entertainment, news

This theme, like WordPress, is licensed under the GPL.
*/
