.editor-styles-wrapper,.entry-content{
  counter-reset:footnotes;
}

a[data-fn].fn{
  counter-increment:footnotes;
  display:inline-flex;
  font-size:smaller;
  text-decoration:none;
  text-indent:-9999999px;
  vertical-align:super;
}

a[data-fn].fn:after{
  content:"[" counter(footnotes) "]";
  float:left;
  text-indent:0;
}