.blp-has-blocks.full-width .wp-block-cover-image .wp-block-cover__inner-container, 
.blp-has-blocks.full-width .wp-block-cover .wp-block-cover__inner-container, 
.blp-has-blocks.fullwidth-centered .wp-block-cover-image .wp-block-cover__inner-container, 
.blp-has-blocks.fullwidth-centered .wp-block-cover .wp-block-cover__inner-container {
    max-width: 1170px;
    width: 100%;
    margin-left: auto;
    margin-right: auto;
}

.blp-has-blocks.fullwidth-centered .wp-block-cover-image .wp-block-cover__inner-container, 
.blp-has-blocks.fullwidth-centered .wp-block-cover .wp-block-cover__inner-container {
    max-width: 670px;
}

.wp-block-separator {
    background-color: rgba(var(--font-color-rgb), 0.05);
    height: 5px;
    margin: 2em 0;
}

.blp-has-blocks .entry-content .alignfull {
    position: relative;
}

.wp-block-embed {
    margin: 0;
}

.wp-block-quote.is-style-large, 
.wp-block-quote.is-large {
    padding: 10% 5%;
}

.blp-has-blocks .wp-block-image figcaption, 
.blp-has-blocks .wp-block-gallery .blocks-gallery-caption, 
.blp-has-blocks .wp-block-embed figcaption {
  margin: 0.8075em 0 0 0;
  font-size: 0.95em;
  color: var(--font-color);
  font-family: var(--secondary-font);
  line-height: 1.3;
  text-align: center;
}

.blp-has-blocks .wp-block-gallery .blocks-gallery-caption {
    width: 100%;
    margin-top: 0;
    margin-bottom: 1.5em;
}

.single .site-main .entry-content .wp-block-gallery .blocks-gallery-item, 
.page .site-main .entry-content .wp-block-gallery .blocks-gallery-item {
    background: none;
    padding-left: 0;
}

.wp-block-file {
    background: rgba(var(--primary-color-rgb), 0.1);
    padding: 2% 4%;
    margin-bottom: 0.7em;
}

.wp-block-file.aligncenter {
    display: table;
    margin-left: auto;
    margin-right: auto;
}

.wp-block-file.alignfull {
    text-align: center;
}

.wp-block-file a {
    display: inline-block;
    color: var(--font-color);
}

.wp-block-file .wp-block-file__button {
    background: var(--primary-color);
    padding: 0.7em 1.5em;
    font-size: 0.9em;
    line-height: 1.3;
}

.wp-block-table.is-style-stripes {
    border-bottom: none;
}

.wp-block-table.is-style-stripes tbody tr:nth-child(2n+1) {
    background: rgba(var(--primary-color-rgb), 0.35);
}

/*============================
WIDGET DEFAULT CSS
============================*/
.wp-block-archives, 
.wp-block-categories, 
.wp-block-latest-comments, 
.wp-block-rss {
    margin: 0;
    padding: 0;
    list-style: none;
}

.wp-block-categories li, 
.wp-block-archives li, 
.wp-block-latest-comments li, 
.wp-block-rss li {
    margin-bottom: 15px;
    padding-bottom: 15px;
    border-bottom: 1px solid rgba(var(--primary-color-rgb), 0.2);
    font-size: 1em;
    font-weight: 400;
    position: relative;
    padding-left: 20px;
}

.wp-block-latest-comments li {
    padding-left: 0;
}

.wp-block-categories li:last-child, 
.wp-block-archives li:last-child,
.wp-block-latest-comments li:last-child, 
.wp-block-rss li:last-child {
	border-bottom: none;
	padding-bottom: 0;
	margin-bottom: 0;
}

.wp-block-categories li::before, 
.wp-block-archives li::before, 
.wp-block-rss li::before{
    content: "";
    background: var(--primary-color);
    width: 6px;
    height: 6px;
    position: absolute;
    left: 0;
    top: 12px;
    border-radius: 100px;
}

.widget_nav_menu ul ul {
	margin-top: 15px;
}

.wp-block-categories li a, 
.wp-block-archives li a, 
.wp-block-latest-comments li a, 
.wp-block-rss li a {
    color: rgba(var(--font-color-rgb), 0.8);
}

.wp-block-categories li a:hover, 
.wp-block-archives li a:hover, 
.wp-block-latest-comments li a:hover, 
.wp-block-rss li a:hover {
    color: var(--primary-color);
}

.block-editor .wp-block-latest-comments p {
    margin-bottom: 0;
}

/*=============================
WIDGET SEARCH
=============================*/
.wp-block-search {
	display: flex;
	flex: 1;
	flex-wrap: wrap;
}

.wp-block-search .wp-block-search__input {
    width: calc(100% - 50px);
	border-radius: 0;
	border-right: none;
	height: 50px;
    font-size: 0.7778em;
    border-color: rgba(var(--primary-color-rgb), 0.3);
}

.wp-block-search .wp-block-search__button {
	width: 50px;
    height: 50px;
    margin: 0;
	padding: 0;
	text-align: center;
	border-radius: 0;
	border: none;
	box-shadow: none;
	background-color: var(--primary-color);
	background-image: url('data:image/svg+xml; utf-8, <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="%23fff" d="M508.5 468.9L387.1 347.5c-2.3-2.3-5.3-3.5-8.5-3.5h-13.2c31.5-36.5 50.6-84 50.6-136C416 93.1 322.9 0 208 0S0 93.1 0 208s93.1 208 208 208c52 0 99.5-19.1 136-50.6v13.2c0 3.2 1.3 6.2 3.5 8.5l121.4 121.4c4.7 4.7 12.3 4.7 17 0l22.6-22.6c4.7-4.7 4.7-12.3 0-17zM208 368c-88.4 0-160-71.6-160-160S119.6 48 208 48s160 71.6 160 160-71.6 160-160 160z"></path></svg>');
	background-repeat: no-repeat;
	background-size: 20px;
	background-position: center;
	text-indent: 60px;
	white-space: nowrap;
	overflow: hidden;
}

.wp-block-search .wp-block-search__button:hover, 
.wp-block-search .wp-block-search__button:active, 
.wp-block-search .wp-block-search__button:focus {
	background-color: var(--font-color);
	background-image: url('data:image/svg+xml; utf-8, <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="%23fff" d="M508.5 468.9L387.1 347.5c-2.3-2.3-5.3-3.5-8.5-3.5h-13.2c31.5-36.5 50.6-84 50.6-136C416 93.1 322.9 0 208 0S0 93.1 0 208s93.1 208 208 208c52 0 99.5-19.1 136-50.6v13.2c0 3.2 1.3 6.2 3.5 8.5l121.4 121.4c4.7 4.7 12.3 4.7 17 0l22.6-22.6c4.7-4.7 4.7-12.3 0-17zM208 368c-88.4 0-160-71.6-160-160S119.6 48 208 48s160 71.6 160 160-71.6 160-160 160z"></path></svg>');
	background-repeat: no-repeat;
	background-size: 20px;
	background-position: center;
}

/*====================================
WIDGET RECENT COMMENTS & ENTRIES
====================================*/
.wp-block-latest-posts {
    counter-reset: listCount;
    margin: 0;
    padding: 0;
    list-style: none;
}

.wp-block-latest-posts li {
    counter-increment: listCount;
    position: relative;
	padding-left: 55px;
    font-size: 1.1112em;
    margin-bottom: 15px;
    min-height: 45px;
}

.wp-block-latest-posts li::before {
    content: "0"counter(listCount);
    font-family: var(--secondary-font);
    color: rgba(var(--primary-color-rgb), 0.5);
    font-size: 2em;
    line-height: 1;
    position: absolute;
    top: 5px;
    left: 0;
}

.wp-block-latest-posts li a {
    color: rgba(var(--font-color-rgb), 0.8);
}

.wp-block-latest-posts li a:hover {
    color: var(--primary-color);
}

/*============================
WIDGET CALENDAR
============================*/
.wp-block-calendar table {
    margin: 0;
}

.wp-block-calendar table caption {
    background: var(--secondary-color);
    padding: 5px;
    font-weight: 600;
}

.wp-block-calendar table tr th,
.wp-block-calendar table tr td {
    padding: 5px 0;
    text-align: center;
    font-weight: 700;
    font-size: 1em;
    line-height: 1.5;
    background: none;
    border: none;
}

.wp-block-calendar table tr td {
    font-weight: 400;
}

.wp-block-calendar table tbody tr td#today {
    background: rgba(var(--primary-color-rgb), 0.15);
}

.wp-block-calendar table tr td a {
    display: block;
}

.wp-block-calendar table tr td a:hover {
    text-decoration: none;
    color: var(--font-color);
}

.wp-block-calendar table tfoot {
    border-top: 1px solid rgba(var(--primary-color-rgb), 0.1);
}

.wp-block-calendar table tfoot td#prev {
    text-align: left;
}

.wp-block-calendar table tfoot td#next {
    text-align: right;
}

/*=========================
WIDGET TAG CLOUD
=========================*/
.wp-block-tag-cloud a {
    display: inline-block;
    color: rgba(var(--font-color-rgb), 0.5);
    margin: 1%;
    line-height: 1.5;
    text-decoration: none;
}

.wp-block-tag-cloud a:hover {
	color: var(--primary-color);
}

/*============================
WIDGET NEWSLETTER
============================*/
.blossomthemes-email-newsletter-wrapper {
    padding: 40px 30px;
}

.widget .blossomthemes-email-newsletter-wrapper .img-holder {
    width: 60px;
    height: 60px;
    border-radius: 100%;
    overflow: hidden;
    margin: 0 auto 20px auto;
    position: relative;
}

.blossomthemes-email-newsletter-wrapper .text-holder {
    text-align: center;
}

.blossomthemes-email-newsletter-wrapper .text-holder h3 {
    margin-top: 0;
    margin-bottom: 0;
    font-size: 1.39em;
    font-family: var(--secondary-font);
    font-weight: 600;
    letter-spacing: 0.5px;
}

.blossomthemes-email-newsletter-wrapper .text-holder span {
    display: block;
    /*margin-top: 15px;*/
}

.blossomthemes-email-newsletter-wrapper form input[type="text"] {
    /*margin-bottom: 20px;*/
    /* border: none; */
}

.blossomthemes-email-newsletter-wrapper form label {
	/*margin-bottom: 20px;*/
}

.blossomthemes-email-newsletter-wrapper form label .check-mark {
    border-color: rgba(var(--font-color-rgb), 0.4);
    background: #fff;
} 

.blossomthemes-email-newsletter-wrapper form input[type="submit"] {
    letter-spacing: 1px;
}

@media screen and (max-width: 1199px) {
    .blp-has-blocks.full-width .wp-block-cover-image .wp-block-cover__inner-container, 
    .blp-has-blocks.full-width .wp-block-cover .wp-block-cover__inner-container, 
    .blp-has-blocks.fullwidth-centered .wp-block-cover-image .wp-block-cover__inner-container, 
    .blp-has-blocks.fullwidth-centered .wp-block-cover .wp-block-cover__inner-container {
        max-width: 1000px;
    }
}

@media screen and (max-width: 1024px) {
    .blp-has-blocks.full-width .wp-block-cover-image .wp-block-cover__inner-container, 
    .blp-has-blocks.full-width .wp-block-cover .wp-block-cover__inner-container, 
    .blp-has-blocks.fullwidth-centered .wp-block-cover-image .wp-block-cover__inner-container, 
    .blp-has-blocks.fullwidth-centered .wp-block-cover .wp-block-cover__inner-container {
        max-width: 768px;
        padding-left: 15px;
        padding-right: 15px;
    }
}

@media screen and (max-width: 767px) {
    .blp-has-blocks.full-width .wp-block-cover-image .wp-block-cover__inner-container, 
    .blp-has-blocks.full-width .wp-block-cover .wp-block-cover__inner-container, 
    .blp-has-blocks.fullwidth-centered .wp-block-cover-image .wp-block-cover__inner-container, 
    .blp-has-blocks.fullwidth-centered .wp-block-cover .wp-block-cover__inner-container {
        max-width: 420px;
    }
}