!function(e){var t={};function n(o){if(t[o])return t[o].exports;var r=t[o]={i:o,l:!1,exports:{}};return e[o].call(r.exports,r,r.exports,n),r.l=!0,r.exports}n.m=e,n.c=t,n.d=function(e,t,o){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:o})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var o=Object.create(null);if(n.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)n.d(o,r,function(t){return e[t]}.bind(null,r));return o},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=120)}({120:function(e,t,n){"use strict";n.r(t);var o;n(121);"undefined"!=typeof jQuery&&(o=jQuery)((function(){function e(e){var t=0;elementorCommon&&(t=jQuery(e.target).parents(".elementor-section-wrap").length>0?jQuery(this).parents(".elementor-add-section").index():-1)>=0&&jQuery(e.target).parents(".elementor-add-section-inline").remove();var n=document.getElementById("envato-elements-magic-button-holder");n||((n=document.createElement("div")).id="envato-elements-magic-button-holder",document.body.appendChild(n));var o={mode:"elementorMagicButton",insertCallback:function(e){if("undefined"!=typeof elementor)if("undefined"!=typeof $e){for(var o=$e.internal("document/history/start-log",{type:"add",title:"Add Envato Elements Content"}),r=0;r<e.content.length;r++)$e.run("document/elements/create",{container:elementor.getPreviewContainer(),model:e.content[r],options:t>=0?{at:t++}:{}});$e.internal("document/history/end-log",{id:o})}else{var i=new Backbone.Model({getTitle:()=>"Test"});elementor.channels.data.trigger("template:before:insert",i);for(var a=0;a<e.content.length;a++)elementor.getPreviewView().addChildElement(e.content[a],t>=0?{at:t++}:null);elementor.channels.data.trigger("template:after:insert",{})}window.envatoElements.closeMagicButton(n)}};window.envatoElements.initMagicButton(n,o)}var t=o("#tmpl-elementor-add-section");if(t.length>0){var n=t.text();n=n.replace('<div class="elementor-add-section-drag-title','<div class="elementor-add-section-area-button elementor-add-envato-button" title="Envato Elements"> <i class="fa fa-folder"></i> </div><div class="elementor-add-section-drag-title'),t.text(n),elementor.on("preview:loaded",(function(){o(elementor.$previewContents[0].body).on("click",".elementor-add-envato-button",e)}))}}))},121:function(e,t,n){}});