import themeColorsMap from './_maps/colors/theme-colors';
import tintsMap from './_maps/colors/tints';
import darkTintsMap from './_maps/colors/dark-tints';

import spacingMap from './_maps/spacing/spacing';

import headingMap from './_maps/typography/heading';
import textMap from './_maps/typography/text';
import lineHeightMap from './_maps/typography/line-height';
import sizeMap from './_maps/typography/size';

import fontWeightMap from './_maps/font/font-weight';

export const themeColors = themeColorsMap;
export const tints = tintsMap;
export const darkTints = darkTintsMap;

export const spacing = spacingMap;

export const heading = headingMap;
export const text = textMap;
export const lineHeight = lineHeightMap;
export const size = sizeMap;
export const fontWeight = fontWeightMap;
