@import '../../../../scss/mixins';

$prevNextButtonSize: 40px;

.slide {
  padding-bottom: $cardResponsiveImagePadding;
  overflow: hidden;
  position: relative;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.1);
}

.image {
  width: 100%;
  position: absolute;
}

.nextArrow,
.prevArrow {
  position: absolute;
  top: -4px;
  width: 30%;
  height: 100%;
  cursor: pointer;
  border: 0;
  outline: none;
  background: transparent;
  z-index: 1;
  display: flex;
  align-items: center;
  min-width: $prevNextButtonSize;
  padding: 0;
  opacity: 0;
  transition: opacity .5s ease-in-out;
}

.nextArrowButton,
.prevArrowButton {
  display: none;
  padding: 0;
  margin: 0;
  cursor: pointer;
  border: 0;
  outline: none;
  background: transparent;
  transition: color 0.3s linear, background-color 0.2s linear;
  color: #fff;
  width: $prevNextButtonSize;
  height: $prevNextButtonSize;
  border-radius: 50%;
}

.nextArrowIcon,
.prevArrowIcon {
  width: 16px;
  height: 31px;
  margin-top: 5px;
  fill: #fff;
  transition: fill 0.3s linear;
}

.nextArrowIcon {
  margin-left: 3px;
}

.prevArrowIcon {
  margin-right: 3px;
}

.nextArrow {
  right: 0;
  justify-content: flex-end;

  &:hover {
    background: linear-gradient(to left, rgba(0, 0, 0, 0.3) 0%, rgba(189, 191, 192, 0) 100%);
    opacity: 1;

    .nextArrowButton {
      display: block;
    }
  }
}

.prevArrow {
  left: 0;
  justify-content: flex-start;

  &:hover {
    background: linear-gradient(to right, rgba(0, 0, 0, 0.3) 0%, rgba(189, 191, 192, 0) 100%);
    opacity: 1;

    .prevArrowButton {
      display: block;
    }
  }
}

.nextArrowButton {
  margin-right: 10px;
}

.prevArrowButton {
  margin-left: 10px;
}
