.elementor-widget-wp-widget-blp_pt_widget {
	margin-bottom: 0;
	display: flex;
	flex-direction: column;
}

.elementor-page section.elementor-element[class*="-section"], 
.elementor-page .content-area, 
.elementor-page .widget-area {
	margin-top: 0;
	margin-bottom: 0;
}

/*--------------------------------------------------------------
# Widgets
--------------------------------------------------------------*/
.elementor-widget {
  margin: 0 0 40px;
  /* Make sure select elements fit in widgets. */
}

.widget-area .elementor-widget:last-child {
  margin-bottom: 0;
}

.elementor-widget select {
  max-width: 100%;
}

.elementor-widget ul {
  margin: 0;
  padding: 0;
  list-style: none;
}

.elementor-widget ul ul {
  margin-top: 15px;
  margin-left: 15px;
}

.elementor-widget ul li {
 	display: block;
	margin-bottom: 25px;
	font-size: 1em;
	font-weight: 500;
}

.elementor-widget ul li:last-child {
  margin-bottom: 0;
}

.elementor-widget ul li a {
  	text-decoration: none;
	color: var(--font-color);
}

.elementor-widget ul li a:hover {
  color: var(--primary-color);
}

.elementor-widget ul li.bttk-social-icon-wrap a:hover {
    color: #fff;
}

.elementor-widget .widget_bttk_popular_post ul li, 
.elementor-widget .widget_bttk_pro_recent_post ul li {
    display: flex;
}

.elementor-widget ul.bttk-itw-holder li {
    display: table;
}

.elementor-widget .blossom-inner-wrap .image-holder {
    width: auto;
    max-width: 200px;
}

.elementor-widget-wp-widget-categories ul li, 
.elementor-widget-wp-widget-archives ul li, 
.elementor-widget-wp-widget-pages ul li, 
.elementor-widget-wp-widget-meta ul li, 
.elementor-widget-wp-widget-nav_menu ul li {
    margin-bottom: 15px;
    padding-bottom: 15px;
    border-bottom: 1px solid rgba(var(--primary-color-rgb), 0.2);
    font-size: 1em;
    font-weight: 400;
    position: relative;
    padding-left: 20px;
}

.elementor-widget-wp-widget-categories ul li:last-child, 
.elementor-widget-wp-widget-archives ul li:last-child, 
.elementor-widget-wp-widget-pages ul li:last-child, 
.elementor-widget-wp-widget-meta ul li:last-child, 
.elementor-widget-wp-widget-nav_menu ul li:last-child {
    border-bottom: none;
    padding-bottom: 0;
    margin-bottom: 0;
}

.elementor-widget-wp-widget-categories ul li::before, 
.elementor-widget-wp-widget-archives ul li::before, 
.elementor-widget-wp-widget-pages ul li::before, 
.elementor-widget-wp-widget-meta ul li::before, 
.elementor-widget-wp-widget-nav_menu ul li::before {
    content: "";
    background: var(--primary-color);
    width: 6px;
    height: 6px;
    position: absolute;
    left: 0;
    top: 12px;
    border-radius: 100px;
}

/*============================
WIDGET CALENDAR
============================*/
.elementor-widget-wp-widget-calendar table {
  margin: 0;
}

.elementor-widget-wp-widget-calendar table caption {
  background: var(--secondary-color);
}

.elementor-widget-wp-widget-calendar table tr th,
.elementor-widget-wp-widget-calendar table tr td {
  padding-left: 0;
  padding-right: 0;
  text-align: center;
  font-weight: 700;
  font-size: 1em;
  line-height: 1.5;
}

.elementor-widget-wp-widget-calendar table tr td {
  font-weight: 400;
}

.elementor-widget-wp-widget-calendar table tbody tr td#today {
  background: rgba(var(--primary-color-rgb), 0.15);
}

.elementor-widget-wp-widget-calendar table tr td a {
  display: block;
}

.elementor-widget-wp-widget-calendar table tr td a:hover {
  text-decoration: none;
  color: var(--font-color);
}

.elementor-widget-wp-widget-calendar table tfoot {
  border-top: 1px solid rgba(var(--primary-color-rgb), 0.1);
}

.elementor-widget-wp-widget-calendar table tfoot td#prev {
  text-align: left;
}

.elementor-widget-wp-widget-calendar table tfoot td#next {
  text-align: right;
}

/*==========================
WIDGET CATEGORY & ARCHIVE
==========================*/
.elementor-widget-wp-widget-categories ul li, 
.elementor-widget-wp-widget-archives ul li {
    color: rgba(var(--font-color-rgb), 0.3);
    display: flex;
    flex-wrap: wrap;
    align-items: center;
}

.elementor-widget-wp-widget-categories ul li a, 
.elementor-widget-wp-widget-archives ul li a {
    flex: 1;
}

/*=============================
WIDGET SEARCH
=============================*/
.elementor-widget-wp-widget-search .search-form .search-field {
    border-color: rgba(var(--primary-color-rgb), 0.3);
}

.elementor-widget-wp-widget-search .search-form .search-submit {
    background-color: var(--primary-color);
}

.elementor-widget-wp-widget-search .search-form .search-submit:hover {
    background-color: var(--font-color);
}

/*====================================
WIDGET RECENT ENTRIES
====================================*/
.elementor-widget-wp-widget-recent-posts ul {
    counter-reset: listCount;
}

.elementor-widget-wp-widget-recent-posts ul li {
    counter-increment: listCount;
    position: relative;
	padding-left: 55px;
	font-size: 1.1112em;
}

.elementor-widget-wp-widget-recent-posts ul li::before {
    content: "0"counter(listCount);
    font-family: var(--secondary-font);
    color: rgba(var(--primary-color-rgb), 0.5);
    font-size: 2em;
    line-height: 1;
    position: absolute;
    top: 5px;
    left: 0;
}

/*============================
WIDGET NEWSLETTER
============================*/
.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget .blossomthemes-email-newsletter-wrapper {
    padding: 40px 30px;
}

.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget .blossomthemes-email-newsletter-wrapper .img-holder {
    width: 60px;
    height: 60px;
    border-radius: 100%;
    overflow: hidden;
    margin: 0 auto 20px auto;
    position: relative;
}

.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget .blossomthemes-email-newsletter-wrapper .text-holder {
    text-align: center;
}

.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget .text-holder h3 {
    margin-top: 0;
    margin-bottom: 0;
    font-size: 1.39em;
    font-family: var(--secondary-font);
    font-weight: 600;
    letter-spacing: 0.5px;
}

.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget .text-holder span {
    display: block;
    margin-top: 15px;
}

.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget form input[type="text"] {
    margin-bottom: 20px;
    border: none;
}

.elementor-widget-wp-widget-blossomthemes_email_newsletter_widget form label {
	margin-bottom: 20px;
}

/*===============================
WIDGET INSTAGRAM 
===============================*/
.elementor-widget-wp-widget-btif_instagram_widget .profile-link {
	display: block;
	margin-top: 10px;
	text-align: center;
	background: var(--font-color);
	border: 1px solid var(--font-color);
	color: #fff;
	font-size: 0.7778em;
	padding: 10px;
	text-decoration: none;
	line-height: 1.5;
}

.elementor-widget-wp-widget-btif_instagram_widget .profile-link:hover {
	background: none;
	color: var(--font-color);
}

.elementor-widget-wp-widget-btif_instagram_widget ul li .instagram-meta {
    left: 0;
    bottom: 0;
    color: #fff;
    filter: progid: DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#a6000000', GradientType=0)
}

.elementor-widget-wp-widget-btif_instagram_widget ul:after {
    content: '';
    display: block;
    clear: both
}

.elementor-widget-wp-widget-btif_instagram_widget ul {
    margin: 0 -1px!important
}

.elementor-widget-wp-widget-btif_instagram_widget ul li {
    float: left;
    width: 33.3333%;
    padding: 0 1px!important;
    margin: 0 0 2px!important;
    position: relative
}

.elementor-widget-wp-widget-btif_instagram_widget ul li .instagram-meta {
	display: flex;
	flex-wrap: wrap;
	align-items: center;
    position: absolute;
    width: 100%;
    padding: 5px 10px;
    opacity: 0;
    -webkit-transition: linear .2s;
    -moz-transition: linear .2s;
    transition: linear .2s;
    background: -moz-linear-gradient(top, transparent, rgba(var(--font-color-rgb), .65) 100%);
    background: -webkit-linear-gradient(top, transparent, rgba(var(--font-color-rgb), .65) 100%);
    background: linear-gradient(to bottom, transparent, rgba(var(--font-color-rgb), .65) 100%)
}

.elementor-widget-wp-widget-btif_instagram_widget ul.photos-4 li .instagram-meta,
.elementor-widget-wp-widget-btif_instagram_widget ul.photos-5 li .instagram-meta {
    display: none
}

.elementor-widget-wp-widget-btif_instagram_widget ul li:hover .instagram-meta {
    opacity: 1
}

.elementor-widget-wp-widget-btif_instagram_widget ul li .instagram-meta .like {
    display: flex;
    flex: 1;
    align-items: center;
    flex-wrap: wrap;
    padding-right: 10px;
}

.elementor-widget-wp-widget-btif_instagram_widget ul li .instagram-meta svg {
	margin-right: 5px;
}

.elementor-widget-wp-widget-btif_instagram_widget ul li img {
    vertical-align: top;
    width: 100%
}

.elementor-widget-wp-widget-btif_instagram_widget ul.photos-1 li {
    width: 100%
}

.elementor-widget-wp-widget-btif_instagram_widget ul.photos-2 li {
    width: 50%
}

.elementor-widget-wp-widget-btif_instagram_widget ul.photos-4 li {
    width: 25%
}

.elementor-widget-wp-widget-btif_instagram_widget ul.photos-5 li {
    width: 20%
}

/*============================
WIDGET AUTHOR BIO
============================*/
.elementor-widget-wp-widget-bttk_author_bio {
    text-align: center;
}

.elementor-widget-wp-widget-bttk_author_bio .image-holder {
    border-radius: 100%;
    overflow: hidden;
    width: 250px;
    height: 250px;
    margin-left: auto;
	margin-right: auto;
	margin-bottom: 30px;
}

.elementor-widget-wp-widget-bttk_author_bio .image-holder img {
    width: 100%;
    height: 100%;
    object-fit: cover;
}

.elementor-widget-wp-widget-bttk_author_bio .title-holder {
    font-size: 1.39em;
    font-family: var(--secondary-font);
    font-weight: 600;
    letter-spacing: 0.5px;
    line-height: 1.3;
    margin-bottom: 10px;
}

.elementor-widget-wp-widget-bttk_author_bio .author-bio-content p {
    margin-top: 0;
    margin-bottom: 20px;
}

.elementor-widget-wp-widget-bttk_author_bio .text-signature {
    background-image: url('data:image/svg+xml; utf-8, <svg xmlns="http://www.w3.org/2000/svg" width="128.31" height="12.679" viewBox="0 0 128.31 12.679"><path d="M1317.685,1743.805s136.174-19.581,127.315,4.494" transform="translate(-1317.614 -1735.793)" fill="none" stroke="%23000" stroke-width="1"/></svg>');
    background-position: center bottom;
    padding-bottom: 15px;
    background-repeat: no-repeat;
	background-size: auto;
	font-family: 'Dancing Script',cursive;
	font-size: 30px;
	color: #000;
	font-style: italic;
	line-height: 1.3;
	margin-bottom: 10px;
}

.elementor-widget-wp-widget-bttk_author_bio .readmore {
    background: var(--font-color);
    color: #fff;
    font-size: 0.7778em;
    font-weight: 700;
    letter-spacing: 0.5px;
	text-decoration: none;
	padding: 10px 30px;
	margin-top: 15px;
	margin-bottom: 0;
    display: block;
}

.elementor-widget-wp-widget-bttk_author_bio .readmore:hover {
	background: var(--primary-color);
}

.site-footer .elementor-widget-wp-widget-bttk_author_bio .readmore:hover {
	background: var(--primary-color);
    color: #fff;
}

.elementor-widget-wp-widget-bttk_author_bio .author-socicons {
	margin-top: 20px;
}

.elementor-widget-wp-widget-bttk_author_bio .author-socicons li {
	margin: 10px 5px 0 5px;
	display: inline-block;
}

.elementor-widget-wp-widget-bttk_author_bio .author-socicons li a {
	display: inline-block;
	width: 36px;
    height: 36px;
    text-align: center;
    background: rgba(var(--primary-color-rgb), 0.3);
    border-radius: 100%;
    line-height: 38px;
    color: rgba(var(--font-color-rgb), 0.8);
}

.elementor-widget-wp-widget-bttk_author_bio .author-socicons li a:hover {
	background: var(--primary-color);
	color: #fff;
}

/*================================
 Popular post style
 ================================*/
 .elementor-widget-wp-widget-bttk_popular_post ul,
 .elementor-widget-wp-widget-bttk_pro_recent_post ul {
    counter-reset: list-count;
}

.elementor-widget-wp-widget-bttk_popular_post ul li,
 .elementor-widget-wp-widget-bttk_pro_recent_post ul li {
    counter-increment: list-count;
    padding-top: 15px;
    padding-left: 15px;
    position: relative;
}

.elementor-widget-wp-widget-bttk_popular_post ul li::before,
 .elementor-widget-wp-widget-bttk_pro_recent_post ul li::before {
    content: counter(list-count);
    position: absolute;
    top: 0;
    left: 0;
    width: 32px;
    height: 32px;
    background: #fff;
    text-align: center;
    line-height: 32px;
    border-radius: 100%;
    font-size: 1.1112em;
    color: var(--primary-color);
    font-weight: 400;
    font-family: var(--secondary-font);
    border: 2px dotted var(--primary-color);
}

.elementor-widget-wp-widget-bttk_popular_post ul li,
.elementor-widget-wp-widget-bttk_pro_recent_post ul li{
	overflow: hidden;
}

.elementor-widget-wp-widget-bttk_popular_post ul li .post-thumbnail,
.elementor-widget-wp-widget-bttk_pro_recent_post ul li .post-thumbnail{
	float: left;
	width: 30%;
	height: auto;
	margin-right: 20px;
}

.elementor-widget-wp-widget-bttk_popular_post ul li .post-thumbnail img,
.elementor-widget-wp-widget-bttk_pro_recent_post ul li .post-thumbnail img{
	vertical-align: top;
	width: 100%;
	height: 100%;
	object-fit: cover;
}

.elementor-widget-wp-widget-bttk_popular_post ul li .entry-header,
.elementor-widget-wp-widget-bttk_pro_recent_post ul li .entry-header{
	overflow: hidden;
}

.elementor-widget-wp-widget-bttk_popular_post ul li .entry-header .entry-meta, 
.elementor-widget-wp-widget-bttk_pro_recent_post ul li .entry-header .entry-meta {
	font-size: 0.7778em;
	line-height: 1.5;
}

.elementor-widget-wp-widget-bttk_popular_post ul li .entry-header .entry-title,
.elementor-widget-wp-widget-bttk_pro_recent_post ul li .entry-header .entry-title{
	font-size: 1.1112em;
	line-height: 1.8;
	margin: 0;
}

.elementor-widget-wp-widget-bttk_popular_post .style-two li .post-thumbnail,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-two li .post-thumbnail{
	width: 100%;
	margin-right: 0;
	margin-bottom: 20px;
	height: auto;
}

.elementor-widget-wp-widget-bttk_popular_post .style-two li .entry-header,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-two li .entry-header{
	width: 100%;
	text-align: center;
	padding: 0 15px;
}

.elementor-widget-wp-widget-bttk_popular_post .style-three li .post-thumbnail,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-three li .post-thumbnail{
	height: 190px;
	margin: 0 0 -40px;
	width: 100%;
}

.elementor-widget-wp-widget-bttk_popular_post .style-three li .entry-header,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-three li .entry-header{
	background: #fff none repeat scroll 0 0;
	margin: 0 auto;
	max-width: 92%;
	padding: 13px 15px 0;
	position: relative;
	text-align: center;
	width: 100%;
}

.elementor-widget-wp-widget-bttk_popular_post ul li .entry-header .cat-links,
.elementor-widget-wp-widget-bttk_pro_recent_post ul li .entry-header .cat-links{
	display: none;
}

.elementor-widget-wp-widget-bttk_popular_post .style-two li .entry-header .cat-links,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-two li .entry-header .cat-links,
.elementor-widget-wp-widget-bttk_popular_post .style-three li .entry-header .cat-links,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-three li .entry-header .cat-links{
	display: block;
	font-size: 0.7778em;
	font-weight: 500;
}

.elementor-widget-wp-widget-bttk_popular_post .style-two li .entry-header .cat-links a,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-two li .entry-header .cat-links a,
.elementor-widget-wp-widget-bttk_popular_post .style-three li .entry-header .cat-links a,
.elementor-widget-wp-widget-bttk_pro_recent_post .style-three li .entry-header .cat-links a{
	margin: 0 3px;
}

/*================================
WIDGET CUSTOM CATEGORY
================================*/
.elementor-widget-wp-widget-bttk_custom_categories ul li {
    background-size: cover !important;
    font-size: 1em;
    margin-bottom: 15px;
}

.elementor-widget-wp-widget-bttk_custom_categories ul li a {
    display: flex;
    flex-wrap: wrap;
    justify-content: center;
    align-items: center;
	color: #fff;
	min-height: 120px;
    padding: 15px;
}

.elementor-widget-wp-widget-bttk_custom_categories ul li a:hover {
    color: #fff;
}

.elementor-widget-wp-widget-bttk_custom_categories ul li .cat-title {
    float: none;
    font-size: 1.1112em;
    font-family: var(--secondary-font);
    letter-spacing: 0.5px;
    margin-right: 10px;
    font-weight: 600;
}

.elementor-widget-wp-widget-bttk_custom_categories ul li .post-count {
    float: none;
    background: var(--primary-color);
    font-size: 0.7778em;
    letter-spacing: 0.5px;
    width: auto;
    height: auto;
    line-height: normal;
    padding: 5px 10px;
}

.elementor-widget-wp-widget-bttk_custom_categories ul li a:hover .post-count, 
.elementor-widget-wp-widget-bttk_custom_categories ul li a:hover:focus .post-count {
	width: auto;
	background: var(--font-color);
}

/*========================
Image text widget
========================*/
.elementor-widget-wp-widget-bttk_image_text_widget ul li{
	position: relative;
}

.elementor-widget-wp-widget-bttk_image_text_widget ul li img {
	width: 100%;
}

.elementor-widget-wp-widget-bttk_image_text_widget ul li .btn-readmore {
	position: absolute;
	width: 70%;
	text-align: center;
	top: 50%;
	left: 50%;
	color: #fff;
	background: #111;
	text-transform: uppercase;
	font-size: 0.7em;
	padding: 15px 20px;
	-webkit-transform: translate(-50%, -50%);
	-moz-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%);
	-webkit-transition: ease 0.2s;
	-moz-transition: ease 0.2s;
	transition: ease 0.2s;
}

.elementor-widget-wp-widget-bttk_image_text_widget ul li .btn-readmore:hover {
	background: var(--primary-color);
	color: #fff;
}

/* .elementor-default .widget-area ul li{
	margin-bottom: 20px;
} */

/*===============================
WIDGET POST CATEGORY SLIDER
===============================*/
.elementor-widget-wp-widget-bttk_posts_category_slider_widget .item {
  	width: 100%;
	min-height: 350px;
	position: relative;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .item img {
	width: 100%;
	height: 100%;
	object-fit: cover;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .item .carousel-title {
	position: absolute;
	bottom: 0;
	left: 0;
	right: 0;
	background: rgba(var(--font-color-rgb), 0.5);
	padding: 3% 5%;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .carousel-title a {
	color: #fff;
	display: inline-block;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .carousel-title a:hover {
	color: var(--primary-color);
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .carousel-title .cat-links {
    display: block;
    font-size: 0.7778em;
    font-weight: 500;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .carousel-title .cat-links a {
    margin: 0 3px;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .carousel-title .cat-links a::after {
	content: ",";
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .carousel-title .cat-links a:last-child::after {
	display: none;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .item .carousel-title .title {
	font-size: 1.1112em;
	margin-top: 5px;
	margin-bottom: 0;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-nav [class*="owl-"] {
	border-radius: 100%;
	background: rgba(var(--font-color-rgb), 0.5);
	left: 10px;
	top: 40%;
	min-height: auto;
	margin: 0;
	width: 40px;
	height: 40px;
	font-size: 0;
	position: absolute;
	-webkit-transition: ease .2s;
	-moz-transition: ease .2s;
	transition: ease .2s;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-nav .owl-next {
	left: auto;
	right: 10px;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-nav [class*="owl-"]:hover {
	background: var(--primary-color);
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-nav [class*="owl-"]:before {
	display: none;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-next::after, 
.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-prev::after {
    background-repeat: no-repeat;
    width: 10px;
    height: 20px;
    position: absolute;
    -webkit-transform: translate(-50%,-50%);
    -moz-transform: translate(-50%,-50%);
    content: '';
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-prev::after {
    background-image: url('data:image/svg+xml; utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 192 512"><path fill="%23fff" d="M4.2 247.5L151 99.5c4.7-4.7 12.3-4.7 17 0l19.8 19.8c4.7 4.7 4.7 12.3 0 17L69.3 256l118.5 119.7c4.7 4.7 4.7 12.3 0 17L168 412.5c-4.7 4.7-12.3 4.7-17 0L4.2 264.5c-4.7-4.7-4.7-12.3 0-17z"></path></svg>');
    top: 50%;
    left: 50%;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-next::after {
    background-image: url('data:image/svg+xml; utf8,<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 192 512"><path fill="%23fff" d="M187.8 264.5L41 412.5c-4.7 4.7-12.3 4.7-17 0L4.2 392.7c-4.7-4.7-4.7-12.3 0-17L122.7 256 4.2 136.3c-4.7-4.7-4.7-12.3 0-17L24 99.5c4.7-4.7 12.3-4.7 17 0l146.8 148c4.7 4.7 4.7 12.3 0 17z"></path></svg>');
    top: 50%;
    left: 50%;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-dots {
	position: static;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-dots .owl-dot {
	background: rgba(var(--font-color-rgb), 0.3);
	margin: 5px;
	width: 25px;
	height: 8px;
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-dots .owl-dot.active, 
.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-carousel .owl-dots .owl-dot:hover {
	background: var(--font-color);
	border-color: var(--font-color);
}

.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-dots .owl-dot span, 
.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-dots .owl-dot:hover span, 
.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-dots .owl-dot span:hover, 
.elementor-widget-wp-widget-bttk_posts_category_slider_widget .owl-theme .owl-dots .owl-dot.active span {
	display: none;
}

/*==============================
WIDGET SOCIAL ICONS
==============================*/
.elementor-widget-wp-widget-bttk_social_links {
	margin-bottom: 20px;
}
.elementor-widget-wp-widget-bttk_social_links ul {
	text-align: center;
	display: flex;
	flex-wrap: wrap;
	align-items: center;
}

.elementor-widget-wp-widget-bttk_social_links ul li {
	margin-right: 15px;
	margin-bottom: 15px;
	padding: 0;
	font-size: 1.1112em;
}

.elementor-widget-wp-widget-bttk_social_links ul li:last-child {
	margin-bottom: 15px;
}

#primary .elementor-widget-wp-widget-bttk_social_links ul li a {
	display: inline-block;
	background: none;
	border-radius: 100%;
	width: 63px;
	height: 63px;
	line-height: 60px;
	border: 1px solid rgba(var(--primary-color-rgb), 0.3);
}

#primary .elementor-widget-wp-widget-bttk_social_links ul li a:hover {
	background: var(--primary-color);
	color: #fff;
}

/*==========================
WIDGET CLIENT LOGO
==========================*/
.elementor-widget-wp-widget-blossom_client_logo_widget .blossom-inner-wrap {
	display: flex;
	flex: 1;
	flex-wrap: wrap;
	justify-content: center;
	align-items: center;
}

.elementor-widget-wp-widget-blossom_client_logo_widget .image-holder {
	padding: 15px 30px;
    display: flex;
    flex-direction: column;
    flex: 1;
    min-width: 150px;
    align-items: center;
    justify-content: center;
}

.elementor-widget-wp-widget-blossom_client_logo_widget .image-holder a {
    display: flex;
    flex-direction: column;
}

.black-white img {
	-webkit-filter: grayscale(1);
	filter: grayscale(1);
}

.black-white:hover img {
	-webkit-filter: grayscale(0);
	filter: grayscale(0);
}

.elementor-widget-wp-widget-blossom_client_logo_widget .image-holder:not(.black-white) a:hover {
	opacity: 0.65;
	filter: alpha(opacity=65);
}

/*===============================
WIDGET CTA
===============================*/
.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .elementor-widget-container > div {
	padding: 5%;
}

.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .elementor-widget-container > div.bttk-cta-bg {
	position: relative;
	z-index: 1;
}

.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .elementor-widget-container > div.bttk-cta-bg::before {
	content: "";
	background: rgba(var(--font-color-rgb), 0.5);
	position: absolute;
	top: 0;
	left: 0;
	width: 100%;
	height: 100%;
	z-index: -1;
}

.content-area .elementor-widget-wp-widget-blossomtheme_companion_cta_widget .elementor-widget-container > div h5 {
	background: none;
	margin-top: 0;
	padding: 0;
	font-size: 1.6665em;
	letter-spacing: 0;
	text-transform: none;
}

.content-area .elementor-widget-wp-widget-blossomtheme_companion_cta_widget .bttk-cta-bg .blossomtheme-cta-container h5,
.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .bttk-cta-bg .text-holder {
	color: #fff;
}

.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .text-holder p {
	margin-top: 0;
	font-size: 0.8888em;
}

.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .btn-cta {
	display: inline-block;
	font-weight: 700;
	font-size: 0.7778em;
	color: #fff;
	letter-spacing: 1px;
	background: var(--primary-color);
	border: 1px solid var(--primary-color);
	padding: 12px 25px;
	text-transform: uppercase;
	text-decoration: none;
	margin: 3px;
}

.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .btn-cta + .btn-cta, 
.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .btn-cta:hover {
	background: none;
	color: var(--primary-color);
}

.elementor-widget-wp-widget-blossomtheme_companion_cta_widget .btn-cta + .btn-cta:hover {
	background: var(--primary-color);
	color: #fff;
}

/*=============================
WIDGET TESTIMONIAL
=============================*/
.elementor-widget-wp-widget-bttk_testimonial_widget .bttk-testimonial-holder {
	padding-top: 40px;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .bttk-testimonial-inner-holder {
	border: 3px solid rgba(var(--font-color-rgb), 0.05);
	border-radius: 5px;
	text-align: center;
	padding: 70px 20px 20px 20px;
	position: relative;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .img-holder {
	width: 100px;
	border-radius: 5px;
	overflow: hidden;
	position: absolute;
	top: -40px;
	left: 0;
	border: 2px solid rgba(var(--font-color-rgb), 0.05);
	padding: 4px;
	background: #fff;
	right: 0;
	margin: 0 auto;
}

.site-footer .elementor-widget-wp-widget-bttk_testimonial_widget .img-holder {
	background: var(--font-color);
	border-color: rgba(255,255,255,0.2);
}

.elementor-widget-wp-widget-bttk_testimonial_widget .img-holder img {
	border-radius: 3px;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .bttk-testimonial-inner-holder .name {
	display: block;
	font-weight: 700;
	line-height: 1.4;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .bttk-testimonial-inner-holder .designation {
	font-size: 0.7778em;
	color: rgba(var(--font-color-rgb), 0.5);
}

.elementor-widget-wp-widget-bttk_testimonial_widget .testimonial-content {
	margin-top: 15px;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .testimonial-content p {
	margin-top: 0;
	margin-bottom: 20px;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .testimonial-content p:last-child {
	margin-bottom: 0;
}

.elementor-widget-wp-widget-bttk_testimonial_widget .testimonial-meta {
    margin-top: 20px;
}

/*============================
WIDGET STAT COUNTER
============================*/
.elementor-widget-wp-widget-blossomthemes_stat_counter_widget .blossomthemes-sc-holder {
	position: relative;
	padding-left: 70px;
	display: flex;
	flex-direction: column-reverse;
}

.elementor-widget-wp-widget-blossomthemes_stat_counter_widget .blossomthemes-sc-holder h5 {
	background: none;
	padding: 0;
	font-size: 1.112em;
	margin-bottom: 0;
	text-align: left;
}

.elementor-widget-wp-widget-blossomthemes_stat_counter_widget .blossomthemes-sc-holder .icon-holder {
	font-size: 3em;
	position: absolute;
	top: 5px;
	left: 0;
	line-height: 1;
	color: var(--primary-color);
}

.elementor-widget-wp-widget-blossomthemes_stat_counter_widget .blossomthemes-sc-holder .hs-counter {
	font-size: 2.6665em;
	font-weight: 700;
	line-height: 1;
}

/*=============================
WIDGET TEAM
=============================*/
.elementor-widget-wp-widget-bttk_description_widget, 
.elementor-widget-wp-widget-bttk_description_widget .image-social-wrap {
    position: relative;
}

.elementor-widget-wp-widget-bttk_description_widget .image-social-wrap .social-profile {
    position: absolute;
    bottom: 0;
    left: 0;
    margin: 0;
    display: block;
}

.elementor-widget-wp-widget-bttk_description_widget .social-profile li {
    margin: 0px;
    font-weight: normal;
    font-size: 0.7778em;
}

.elementor-widget-wp-widget-bttk_description_widget .social-profile li a {
    display: inline-block;
    color: #6a6a6a;
	background: #f5f5f5;
    border: none;
    border-radius: 0;
    width: 37px;
    height: 37px;
    text-align: center;
    line-height: 37px;
}

.elementor-widget-wp-widget-bttk_description_widget .social-profile li a:hover {
    background: var(--primary-color);
    color: #fff;
}

.elementor-widget-wp-widget-bttk_description_widget .text-holder {
    width: 100%;
    padding: 0;
    margin-top: 20px;
}

.elementor-widget-wp-widget-bttk_description_widget .text-holder .name {
    display: block;
    font-weight: 600;
    font-family: var(--secondary-font);
    font-size: 1.1112em;
    line-height: 1.5;
    letter-spacing: 0.5px;
}

.elementor-widget-wp-widget-bttk_description_widget .text-holder .designation {
    display: block;
    font-size: 0.8888em;
    letter-spacing: 0.5px;
    line-height: 1.5;
    color: rgba(var(--font-color-rgb), 0.8);
}

.elementor-widget-wp-widget-bttk_description_widget .bttk-team-holder-modal.show {
    display: none !important;
}

/*==========================
WIDGET ICON TEXT
==========================*/
.elementor-widget-wp-widget-bttk_icon_text_widget .rtc-itw-inner-holder {
	display: flex;
	flex: 1;
	flex-direction: column;
	text-align: center;
}

.elementor-widget-wp-widget-bttk_icon_text_widget .rtc-itw-inner-holder .icon-holder {
	font-size: 3em;
	line-height: 1;
	color: var(--primary-color);
}

.elementor-widget-wp-widget-bttk_icon_text_widget .rtc-itw-inner-holder .text-holder {
	order: 2;
	margin-top: 40px;
}

.content-area .elementor-widget-wp-widget-bttk_icon_text_widget .rtc-itw-inner-holder .text-holder h5 {
	font-size: 1.1112em;
	text-align: center;
	background: none;
	padding: 0;
	margin-top: 0;
	margin-bottom: 0;
}

.elementor-widget-wp-widget-bttk_icon_text_widget .text-holder .btn-readmore {
	display: inline-block;
	font-weight: 700;
	font-size: 0.7778em;
	color: #fff;
	letter-spacing: 1px;
	background: var(--primary-color);
	border: none;
	padding: 13px 30px;
	text-transform: uppercase;
	text-decoration: none;
}

.elementor-widget-wp-widget-bttk_icon_text_widget .text-holder .btn-readmore:hover {
	background: var(--font-color);
	color: #fff;
}

/*===========================
WIDGET CONTACT SOCIAL
===========================*/
.elementor-widget-wp-widget-bttk_contact_social_links ul.contact-list li {
	margin-bottom: 5px;
}

.elementor-widget-wp-widget-bttk_contact_social_links ul.contact-list li:first-child {
	margin-bottom: 40px;
}

.elementor-widget-wp-widget-bttk_contact_social_links ul.contact-list li span {
	margin-right: 10px;
	font-family: var(--secondary-font);
	font-weight: 600;
	letter-spacing: 0.2px;
}

.elementor-widget-wp-widget-bttk_contact_social_links .contact-list-title {
	display: none;
}

.elementor-widget-wp-widget-bttk_contact_social_links .social-networks {
	margin-top: 40px;
}

.elementor-widget-wp-widget-bttk_contact_social_links .social-networks .contact-list-title {
	display: block;
	color: rgba(var(--font-color-rgb), 0.8);
}

.elementor-widget-wp-widget-bttk_contact_social_links .social-networks li {
	margin-top: 10px;
	margin-bottom: 0;
	margin-right: 10px;
	display: inline-block;
	font-size: 1.1112em;
}

.elementor-widget-wp-widget-bttk_contact_social_links .social-networks li a {
	display: inline-block;
	color: var(--primary-color);
	padding: 5px;
}

.widget-area .elementor-widget-wp-widget-bttk_contact_social_links .social-networks li a {
	color: var(--font-color);
}

.elementor-widget-wp-widget-bttk_contact_social_links .social-networks li a:hover {
	color: var(--primary-color);
}

/*========================
WIDGET FAQ
========================*/
.elementor-widget-wp-widget-blp_faq_widget .faq-block {
    background: rgba(var(--primary-color-rgb), 0.1);
	margin-bottom: 20px;
    text-align: left;
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block:last-child {
	margin-bottom: 0;
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block .faq-title {
    background: none;
    color: var(--font-color);
    padding: 0;
    font-family: var(--secondary-font);
    font-weight: 600;
    font-size: 1em;
    line-height: 1.5;
    width: 100%;
    text-align: left;
	position: relative;
	padding: 15px 30px 15px 15px;
	-webkit-transition: all ease 0.35s;
	-moz-transition: all ease 0.35s;
	transition: all ease 0.35s;
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block .faq-title:hover {
	background: none;
	color: var(--primary-color);
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block .faq-title::after {
    content: "";
    background-image: url('data:image/svg+xml; utf-8, <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path fill="%23fbaca5" d="M441.9 167.3l-19.8-19.8c-4.7-4.7-12.3-4.7-17 0L224 328.2 42.9 147.5c-4.7-4.7-12.3-4.7-17 0L6.1 167.3c-4.7 4.7-4.7 12.3 0 17l209.4 209.4c4.7 4.7 12.3 4.7 17 0l209.4-209.4c4.7-4.7 4.7-12.3 0-17z"></path></svg>');
    background-repeat: no-repeat;
    background-position: center;
    width: 18px;
    height: 18px;
    position: absolute;
	top: 21px;
	right: 15px;
	-webkit-transition: all ease 0.35s;
	-moz-transition: all ease 0.35s;
	transition: all ease 0.35s;
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block.active .faq-title::after {
	-webkit-transform: rotate(180deg);
	-moz-transform: rotate(180deg);
	transform: rotate(180deg);
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block .faq-content {
    font-size: 0.8888em;
	color: rgba(var(--font-color-rgb), 0.8);
	padding: 20px 15px;
	border-top: 1px solid #fff;
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block .faq-content p {
    margin-top: 0;
    margin-bottom: 20px;
}

.elementor-widget-wp-widget-blp_faq_widget .faq-block .faq-content p:last-child {
	margin-bottom: 0;
}

/*========================
WOOCOMMERCE WIDGETS
========================*/
/*==============================
Sidebar cart widget
==============================*/
.elementor-widget-wp-widget-woocommerce_widget_cart ul li{
	padding: 0 0 10px 30px;
	border-bottom: 1px solid #e5e5e5;
	margin: 0 0 10px;
	position: relative;
	font-size: 1em;
	text-transform: none;
	min-height: 85px;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li a {
	font-size: 0.8888em;
	font-family: var(--primary-font);
	color: #262525;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li .remove{
	position: absolute;
	top: 8px;
	left: 0;
	font-size: 0;
	width: 20px;
	height: 20px;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li .remove:hover,
.elementor-widget-wp-widget-woocommerce_widget_cart ul li .remove:focus{background: none;}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li .remove:after{
	position: absolute;
	top: 0;
	left: 0;
	content: '';
	background-image: url('data:image/svg+xml; utf-8, <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="%23e2401c" d="M256 8C119 8 8 119 8 256s111 248 248 248 248-111 248-248S393 8 256 8zm121.6 313.1c4.7 4.7 4.7 12.3 0 17L338 377.6c-4.7 4.7-12.3 4.7-17 0L256 312l-65.1 65.6c-4.7 4.7-12.3 4.7-17 0L134.4 338c-4.7-4.7-4.7-12.3 0-17l65.6-65-65.6-65.1c-4.7-4.7-4.7-12.3 0-17l39.6-39.6c4.7-4.7 12.3-4.7 17 0l65 65.7 65.1-65.6c4.7-4.7 12.3-4.7 17 0l39.6 39.6c4.7 4.7 4.7 12.3 0 17L312 256l65.6 65.1z"></path></svg>');
	background-repeat: no-repeat;
	width: 20px;
	height: 20px;
	color: #e2401c;
	font-size: 0.8888em;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul.product_list_widget li img{
	width: 75px;
	float: right;
	margin-right: 0;
	margin-left: 4px;
	border-radius: 5px;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li a:not(.button){
	font-weight: 400;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li .variation{
	padding-left: 0;
	border-left: 0;
}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li .variation dt{font-weight: 400;}

.elementor-widget-wp-widget-woocommerce_widget_cart ul li .variation dd{
	margin: 0
}

.elementor-widget-wp-widget-woocommerce_widget_cart .total{
	border-top: 0;
	padding-top: 0;
	padding-bottom: 10px;
	font-size: 0.8888em;
	border-bottom: 1px solid #e5e5e5;
	text-align: center;
	display: flex;
	flex: auto;
	flex-wrap: wrap;
}

.elementor-widget-wp-widget-woocommerce_widget_cart .total strong{
	font-weight: 600;
	color: var(--font-color);
	display: flex;
	flex-direction: column;
	text-align: left;
	flex: 1;
}

.elementor-widget-wp-widget-woocommerce_widget_cart .buttons .button{
	text-decoration: none;
	margin-bottom: 10px;
	display: block;
	background: var(--font-color);
	color: #fff;
	text-align: center;
	font-size: 0.7778em;
	font-weight: 600;
	letter-spacing: 1px;
	border-radius: 0;
	text-transform: uppercase;
	padding: 12px 30px;
	-webkit-transition: linear 0.2s;
	-moz-transition: linear 0.2s;
	transition: linear 0.2s;
	position: relative;
}

.elementor-widget-wp-widget-woocommerce_widget_cart .buttons .button:hover,
.elementor-widget-wp-widget-woocommerce_widget_cart .buttons .button:focus{
	background: var(--primary-color);
	color: #fff;
}

/*===========================================
Sidebar product search form
==========================================*/
.elementor-widget-wp-widget-woocommerce_product_search .woocommerce-product-search{
	background: none;
	border-radius: 5px;
	margin: 0 3px 0 0;
	width: 100%;
	padding: 0;
	border: 1px solid #e5e5e5;
}

.elementor-widget-wp-widget-woocommerce_product_search .woocommerce-product-search:after{
	content: '';
	display: block;
	clear: both;
}

.elementor-widget-wp-widget-woocommerce_product_search .woocommerce-product-search input[type="search"]{
	background: none;
	border: 0;
	border-radius: 0;
	float: left;
	margin: 0;
	padding: 10px 15px;
	font-size: 0.8888em;
	width: calc(100% - 50px);
	height: 50px;
	font-weight: 400;
}

/*===================================
Widget rating filter
===================================*/
.elementor-widget-wp-widget-rating_filter ul li .star-rating{
	vertical-align: top;
	margin-top: 7px;
}  
  
/*===================================
Product list
===================================*/
ul.product_list_widget li img{
	float: left;
	width: 75px;
	margin-left: 0;
	margin-right: 15px;
}

ul.product_list_widget li{
	margin: 0 0 20px;
	text-transform: none;
	font-weight: 400;
	font-size: 0.8888em;
	min-height: 75px;
}

ul.product_list_widget li a {
	font-weight: 400;
}

ul.product_list_widget li .product-title{
	display: block;
	color: var(--font-color);
	font-family: var(--primary-font);
}

ul.product_list_widget li .product-title:hover,
ul.product_list_widget li .product-title:focus{
	color: var(--primary-color);
}

ul.product_list_widget li .amount{
	color: #b5b5b5;
	font-weight: 500;
}

ul.product_list_widget li ins,
ul.product_list_widget li ins .amount{
	background: none;
	color: var(--font-color);
}

ul.product_list_widget li ins{
	margin-left: 10px;
}

ul.product_list_widget li .star-rating{
	margin: 0 0 5px;
}

/*===================================
Sidebar layered nav dropdown
===================================*/
.select2-container--default .select2-selection--multiple .select2-selection__rendered {
	padding: 5px;
}

.elementor-widget-wp-widget-layered-nav .woocommerce-widget-layered-nav-dropdown ul li.select2-selection__choice{
	margin: 5px;
	padding: 0 10px;
	border-bottom: 1px solid #aaa;
}

.elementor-widget-wp-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item {
	position: relative;
}

.elementor-widget-wp-widget-layered-nav .woocommerce-widget-layered-nav-dropdown ul li.select2-search--inline {
	border-bottom: none;
}

.elementor-widget-wp-widget-layered-nav ul li input[type="text"]{
	width: 100% !important;
}

.elementor-widget-wp-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item a, 
.elementor-widget-wp-widget-layered_nav_filters ul li a {
	position: relative;
	padding-left: 30px;
}

.elementor-widget-wp-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item a::before, 
.elementor-widget-wp-widget-layered_nav_filters ul li a:before {
	content: "";
	width: 16px;
	height: 16px;
	border: 1px solid #ddd;
	border-radius: 2px;
	position: absolute;
	top: 4px;
	left: 0;
	background-image: url('data:image/svg+xml; utf-8, <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path fill="%23fff" d="M173.898 439.404l-166.4-166.4c-9.997-9.997-9.997-26.206 0-36.204l36.203-36.204c9.997-9.998 26.207-9.998 36.204 0L192 312.69 432.095 72.596c9.997-9.997 26.207-9.997 36.204 0l36.203 36.204c9.997 9.997 9.997 26.206 0 36.204l-294.4 294.401c-9.998 9.997-26.207 9.997-36.204-.001z"></path></svg>');
	background-repeat: no-repeat;
	background-size: 0px;
	background-position: center;
	-webkit-transition: all ease 0.35s;
	-moz-transition: all ease 0.35s;
	transition: all ease 0.35s;
}

.elementor-widget-wp-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item a:hover:before, 
.elementor-widget-wp-widget-layered_nav_filters ul li a:hover:before {
	border-color: var(--primary-color);
}

.elementor-widget-wp-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item.chosen a::before, 
.elementor-widget-wp-widget-layered_nav_filters ul li.chosen a:before {
	background-size: 10px;
	background-color: var(--primary-color);
	border-color: var(--primary-color);
}

.elementor-widget-wp-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item .count {
	display: inline-block;
	float: right;
	border: 1px solid #ddd;
	line-height: 1.3;
	padding: 0 5px;
	border-radius: 50px;
	color: #999596;
}
  
/*=============================
Sidebar price filter
============================*/
.elementor-widget-wp-widget-price_filter .ui-slider-horizontal{
	height: 5px;
	background: #eee;
	margin-left: 0;
	margin-right: 0;
	border-radius: 0;
	margin-bottom: 25px;
}

.elementor-widget-wp-widget-price_filter .ui-slider .ui-slider-handle{
	background: #fff;
	width: 15px;
	height: 15px;
	top: -5px;
	border-radius: 100%;
	box-shadow: 5px 0px 15px rgba(136, 206, 208, 0.3);
	border: 3px solid var(--primary-color);
}

.elementor-widget-wp-widget-price_filter .ui-slider .ui-slider-handle.ui-state-hover, 
.elementor-widget-wp-widget-price_filter .ui-slider .ui-slider-handle.ui-state-focus, 
.elementor-widget-wp-widget-price_filter .ui-slider .ui-slider-handle.ui-state-active {
	width: 22px;
	height: 22px;
	top: -8px;
}

.elementor-widget-wp-widget-price_filter .ui-slider .ui-slider-range{
	background: var(--primary-color);
}

.elementor-widget-wp-widget-price_filter .price_slider_amount {
	font-size: 1em;
	display: flex;
	flex-wrap: wrap;
	justify-content: center;
	align-items: center;
	flex: 1;
}

.elementor-widget-wp-widget-price_filter .price_slider_amount .button{
	font-size: 0.6666em;
	font-weight: 700;
	letter-spacing: 1px;
	color: #fff;
	background: var(--primary-color);
	border-radius: 50px;
	border: 2px solid var(--primary-color);
	text-transform: uppercase;
	padding: 16px 30px;
	-webkit-transition: linear 0.2s;
	-moz-transition: linear 0.2s;
	transition: linear 0.2s;
	position: relative;
}

.elementor-widget-wp-widget-price_filter .price_slider_amount .button:hover,
.elementor-widget-wp-widget-price_filter .price_slider_amount .button:focus{
	color: var(--primary-color);
	background: none;
}

.elementor-widget-wp-widget-price_filter .price_slider_amount .price_label{
	font-size: 0.7778em;
	color: #999;
	display: flex;
	flex: 1;
	margin-top: 0;
	justify-content: flex-end;
	font-weight: 600;
	letter-spacing: 1px;
}

.elementor-widget-wp-widget-price_filter .price_slider_amount .price_label > span {
	display: inline-block;
	margin: 0 5px;
}