<?php
return array(
			'title'         => __( 'Call to Action 3', 'alara' ),
			'categories'    => array( 'alara-cta' ),
			'keywords'		=> array( 'newsletter', 'column', 'button' ),
			'viewportWidth' => 1280,
			'content'       => '<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:group {"style":{"border":{"width":"1px"}},"borderColor":"septenary"} -->
<div class="wp-block-group has-border-color has-septenary-border-color" style="border-width:1px"><!-- wp:spacer {"height":48} -->
<div style="height:48px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:paragraph {"align":"center","textColor":"quaternary"} -->
<p class="has-text-align-center has-quaternary-color has-text-color">___ <mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-foreground-color">NEWSLETTER</mark> ___</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"small"} -->
<p class="has-text-align-center has-small-font-size">Discover our latest news and new releases.</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":18} -->
<div style="height:18px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center"}} -->
<div class="wp-block-buttons"><!-- wp:button {"className":"is-style-outline"} -->
<div class="wp-block-button is-style-outline"><a class="wp-block-button__link">Sign Up</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons -->

<!-- wp:spacer {"height":48} -->
<div style="height:48px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:group {"style":{"border":{"width":"1px"}},"borderColor":"septenary"} -->
<div class="wp-block-group has-border-color has-septenary-border-color" style="border-width:1px"><!-- wp:spacer {"height":48} -->
<div style="height:48px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:paragraph {"align":"center","textColor":"quaternary"} -->
<p class="has-text-align-center has-quaternary-color has-text-color">___ <mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-foreground-color">HOW TO FIND US</mark> ___</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"small"} -->
<p class="has-text-align-center has-small-font-size">We are sure to have a location near you.</p>
<!-- /wp:paragraph -->

<!-- wp:spacer {"height":18} -->
<div style="height:18px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"layout":{"type":"flex","justifyContent":"center"}} -->
<div class="wp-block-buttons"><!-- wp:button {"backgroundColor":"quaternary"} -->
<div class="wp-block-button"><a class="wp-block-button__link has-quaternary-background-color has-background">Search</a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons -->

<!-- wp:spacer {"height":48} -->
<div style="height:48px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer --></div>
<!-- /wp:group --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
