.customize-control-zta-sortable ul.ui-sortable {
  cursor: default;
}

.customize-control-zta-sortable ul.ui-sortable .dashicons-visibility {
  cursor: pointer;
}

.customize-control-zta-sortable ul.ui-sortable li {
  padding: 5px 10px;
  border: 1px solid #333;
  background: #fff;
  cursor: move;
}

.customize-control-zta-sortable ul.ui-sortable li .dashicons.dashicons-menu {
  float: right;
}

.customize-control-zta-sortable ul.ui-sortable li .dashicons.visibility {
  margin-right: 10px;
}

.customize-control-zta-sortable ul.ui-sortable li.invisible {
  color: #aaa;
  border: 1px dashed #aaa;
}

.customize-control-zta-sortable ul.ui-sortable li.invisible .dashicons.visibility {
  color: #aaa;
}
