<?php
return array(
	'title'			=> __( 'Pricing Table 4', 'alara' ),
	'categories'	=> array( 'alara-pricing-tables' ),
	'keywords'		=> array( 'column' ),
	'viewportWidth'	=> 1280,
	'content'		=> '<!-- wp:columns {"align":""} -->
<div class="wp-block-columns"><!-- wp:column {"style":{"spacing":{"padding":{"bottom":"60px"}}},"backgroundColor":"tertiary","textColor":"white"} -->
<div class="wp-block-column has-white-color has-tertiary-background-color has-text-color has-background" style="padding-bottom:60px"><!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size" id="tier-1"><strong>Tier 1</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$9</strong> <sub><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-octonary-color">/ month</mark></sub></p>
<!-- /wp:paragraph -->

<!-- wp:list {"backgroundColor":"tertiary"} -->
<ul class="has-tertiary-background-color has-background">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"octonary","textColor":"octonary","className":"is-style-outline"} -->
<div class="wp-block-button is-style-outline"><a class="wp-block-button__link has-octonary-color has-octonary-background-color has-text-color has-background"><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-black-color"><strong>Sign Up</strong></mark></a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"bottom":"60px"}}},"backgroundColor":"quaternary","textColor":"white"} -->
<div class="wp-block-column has-white-color has-quaternary-background-color has-text-color has-background" style="padding-bottom:60px"><!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size" id="tier-1"><strong>Tier 2</strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$14</strong> <sub><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-octonary-color">/ month</mark></sub></p>
<!-- /wp:paragraph -->

<!-- wp:list {"backgroundColor":"quaternary"} -->
<ul class="has-quaternary-background-color has-background">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"octonary","textColor":"octonary","className":"is-style-outline"} -->
<div class="wp-block-button is-style-outline"><a class="wp-block-button__link has-octonary-color has-octonary-background-color has-text-color has-background"><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-black-color"><strong>Sign Up</strong></mark></a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column -->

<!-- wp:column {"style":{"spacing":{"padding":{"bottom":"60px"}}},"backgroundColor":"quinary","textColor":"white"} -->
<div class="wp-block-column has-white-color has-quinary-background-color has-text-color has-background" style="padding-bottom:60px"><!-- wp:paragraph {"align":"center","fontSize":"large"} -->
<p class="has-text-align-center has-large-font-size" id="tier-1"><strong>Tier 3 </strong></p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center","fontSize":"medium"} -->
<p class="has-text-align-center has-medium-font-size"><strong>$19</strong> <sub><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-octonary-color">/ month</mark></sub></p>
<!-- /wp:paragraph -->

<!-- wp:list {"backgroundColor":"quinary"} -->
<ul class="has-quinary-background-color has-background">' . alara_pattern_content( 'list' ) . '</ul>
<!-- /wp:list -->

<!-- wp:spacer {"height":20} -->
<div style="height:20px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:buttons {"contentJustification":"center"} -->
<div class="wp-block-buttons is-content-justification-center"><!-- wp:button {"backgroundColor":"octonary","textColor":"octonary","className":"is-style-outline"} -->
<div class="wp-block-button is-style-outline"><a class="wp-block-button__link has-octonary-color has-octonary-background-color has-text-color has-background"><mark style="background-color:rgba(0, 0, 0, 0)" class="has-inline-color has-black-color"><strong>Sign Up</strong></mark></a></div>
<!-- /wp:button --></div>
<!-- /wp:buttons --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
