{
  "fa fa-500px": {
    "value": "fab fa-500px",
    "library": "fa-brands"
  },
  "fa fa-address-book-o": {
    "value": "far fa-address-book",
    "library": "fa-regular"
  },
  "fa fa-address-card-o": {
    "value": "far fa-address-card",
    "library": "fa-regular"
  },
  "fa fa-adn": {
    "value": "fab fa-adn",
    "library": "fa-brands"
  },
  "fa fa-amazon": {
    "value": "fab fa-amazon",
    "library": "fa-brands"
  },
  "fa fa-android": {
    "value": "fab fa-android",
    "library": "fa-brands"
  },
  "fa fa-angellist": {
    "value": "fab fa-angellist",
    "library": "fa-brands"
  },
  "fa fa-apple": {
    "value": "fab fa-apple",
    "library": "fa-brands"
  },
  "fa fa-area-chart": {
    "value": "fas fa-chart-area",
    "library": "fa-solid"
  },
  "fa fa-arrow-circle-o-down": {
    "value": "far fa-arrow-alt-circle-down",
    "library": "fa-regular"
  },
  "fa fa-arrow-circle-o-left": {
    "value": "far fa-arrow-alt-circle-left",
    "library": "fa-regular"
  },
  "fa fa-arrow-circle-o-right": {
    "value": "far fa-arrow-alt-circle-right",
    "library": "fa-regular"
  },
  "fa fa-arrow-circle-o-up": {
    "value": "far fa-arrow-alt-circle-up",
    "library": "fa-regular"
  },
  "fa fa-arrows": {
    "value": "fas fa-arrows-alt",
    "library": "fa-solid"
  },
  "fa fa-arrows-alt": {
    "value": "fas fa-expand-arrows-alt",
    "library": "fa-solid"
  },
  "fa fa-arrows-h": {
    "value": "fas fa-arrows-alt-h",
    "library": "fa-solid"
  },
  "fa fa-arrows-v": {
    "value": "fas fa-arrows-alt-v",
    "library": "fa-solid"
  },
  "fa fa-asl-interpreting": {
    "value": "fas fa-american-sign-language-interpreting",
    "library": "fa-solid"
  },
  "fa fa-automobile": {
    "value": "fas fa-car",
    "library": "fa-solid"
  },
  "fa fa-bandcamp": {
    "value": "fab fa-bandcamp",
    "library": "fa-brands"
  },
  "fa fa-bank": {
    "value": "fas fa-university",
    "library": "fa-solid"
  },
  "fa fa-bar-chart": {
    "value": "far fa-chart-bar",
    "library": "fa-regular"
  },
  "fa fa-bar-chart-o": {
    "value": "far fa-chart-bar",
    "library": "fa-regular"
  },
  "fa fa-bathtub": {
    "value": "fas fa-bath",
    "library": "fa-solid"
  },
  "fa fa-battery": {
    "value": "fas fa-battery-full",
    "library": "fa-solid"
  },
  "fa fa-battery-0": {
    "value": "fas fa-battery-empty",
    "library": "fa-solid"
  },
  "fa fa-battery-1": {
    "value": "fas fa-battery-quarter",
    "library": "fa-solid"
  },
  "fa fa-battery-2": {
    "value": "fas fa-battery-half",
    "library": "fa-solid"
  },
  "fa fa-battery-3": {
    "value": "fas fa-battery-three-quarters",
    "library": "fa-solid"
  },
  "fa fa-battery-4": {
    "value": "fas fa-battery-full",
    "library": "fa-solid"
  },
  "fa fa-behance": {
    "value": "fab fa-behance",
    "library": "fa-brands"
  },
  "fa fa-behance-square": {
    "value": "fab fa-behance-square",
    "library": "fa-brands"
  },
  "fa fa-bell-o": {
    "value": "far fa-bell",
    "library": "fa-regular"
  },
  "fa fa-bell-slash-o": {
    "value": "far fa-bell-slash",
    "library": "fa-regular"
  },
  "fa fa-bitbucket": {
    "value": "fab fa-bitbucket",
    "library": "fa-brands"
  },
  "fa fa-bitbucket-square": {
    "value": "fab fa-bitbucket",
    "library": "fa-brands"
  },
  "fa fa-bitcoin": {
    "value": "fab fa-btc",
    "library": "fa-brands"
  },
  "fa fa-black-tie": {
    "value": "fab fa-black-tie",
    "library": "fa-brands"
  },
  "fa fa-bluetooth": {
    "value": "fab fa-bluetooth",
    "library": "fa-brands"
  },
  "fa fa-bluetooth-b": {
    "value": "fab fa-bluetooth-b",
    "library": "fa-brands"
  },
  "fa fa-bookmark-o": {
    "value": "far fa-bookmark",
    "library": "fa-regular"
  },
  "fa fa-btc": {
    "value": "fab fa-btc",
    "library": "fa-brands"
  },
  "fa fa-building-o": {
    "value": "far fa-building",
    "library": "fa-regular"
  },
  "fa fa-buysellads": {
    "value": "fab fa-buysellads",
    "library": "fa-brands"
  },
  "fa fa-cab": {
    "value": "fas fa-taxi",
    "library": "fa-solid"
  },
  "fa fa-calendar": {
    "value": "fas fa-calendar-alt",
    "library": "fa-solid"
  },
  "fa fa-calendar-check-o": {
    "value": "far fa-calendar-check",
    "library": "fa-regular"
  },
  "fa fa-calendar-minus-o": {
    "value": "far fa-calendar-minus",
    "library": "fa-regular"
  },
  "fa fa-calendar-o": {
    "value": "far fa-calendar",
    "library": "fa-regular"
  },
  "fa fa-calendar-plus-o": {
    "value": "far fa-calendar-plus",
    "library": "fa-regular"
  },
  "fa fa-calendar-times-o": {
    "value": "far fa-calendar-times",
    "library": "fa-regular"
  },
  "fa fa-caret-square-o-down": {
    "value": "far fa-caret-square-down",
    "library": "fa-regular"
  },
  "fa fa-caret-square-o-left": {
    "value": "far fa-caret-square-left",
    "library": "fa-regular"
  },
  "fa fa-caret-square-o-right": {
    "value": "far fa-caret-square-right",
    "library": "fa-regular"
  },
  "fa fa-caret-square-o-up": {
    "value": "far fa-caret-square-up",
    "library": "fa-regular"
  },
  "fa fa-cc": {
    "value": "far fa-closed-captioning",
    "library": "fa-regular"
  },
  "fa fa-cc-amex": {
    "value": "fab fa-cc-amex",
    "library": "fa-brands"
  },
  "fa fa-cc-diners-club": {
    "value": "fab fa-cc-diners-club",
    "library": "fa-brands"
  },
  "fa fa-cc-discover": {
    "value": "fab fa-cc-discover",
    "library": "fa-brands"
  },
  "fa fa-cc-jcb": {
    "value": "fab fa-cc-jcb",
    "library": "fa-brands"
  },
  "fa fa-cc-mastercard": {
    "value": "fab fa-cc-mastercard",
    "library": "fa-brands"
  },
  "fa fa-cc-paypal": {
    "value": "fab fa-cc-paypal",
    "library": "fa-brands"
  },
  "fa fa-cc-stripe": {
    "value": "fab fa-cc-stripe",
    "library": "fa-brands"
  },
  "fa fa-cc-visa": {
    "value": "fab fa-cc-visa",
    "library": "fa-brands"
  },
  "fa fa-chain": {
    "value": "fas fa-link",
    "library": "fa-solid"
  },
  "fa fa-chain-broken": {
    "value": "fas fa-unlink",
    "library": "fa-solid"
  },
  "fa fa-check-circle-o": {
    "value": "far fa-check-circle",
    "library": "fa-regular"
  },
  "fa fa-check-square-o": {
    "value": "far fa-check-square",
    "library": "fa-regular"
  },
  "fa fa-chrome": {
    "value": "fab fa-chrome",
    "library": "fa-brands"
  },
  "fa fa-circle-o": {
    "value": "far fa-circle",
    "library": "fa-regular"
  },
  "fa fa-circle-o-notch": {
    "value": "fas fa-circle-notch",
    "library": "fa-solid"
  },
  "fa fa-circle-thin": {
    "value": "far fa-circle",
    "library": "fa-regular"
  },
  "fa fa-clipboard": {
    "value": "far fa-clipboard",
    "library": "fa-regular"
  },
  "fa fa-clock-o": {
    "value": "far fa-clock",
    "library": "fa-regular"
  },
  "fa fa-clone": {
    "value": "far fa-clone",
    "library": "fa-regular"
  },
  "fa fa-close": {
    "value": "fas fa-times",
    "library": "fa-solid"
  },
  "fa fa-cloud-download": {
    "value": "fas fa-cloud-download-alt",
    "library": "fa-solid"
  },
  "fa fa-cloud-upload": {
    "value": "fas fa-cloud-upload-alt",
    "library": "fa-solid"
  },
  "fa fa-cny": {
    "value": "fas fa-yen-sign",
    "library": "fa-solid"
  },
  "fa fa-code-fork": {
    "value": "fas fa-code-branch",
    "library": "fa-solid"
  },
  "fa fa-codepen": {
    "value": "fab fa-codepen",
    "library": "fa-brands"
  },
  "fa fa-codiepie": {
    "value": "fab fa-codiepie",
    "library": "fa-brands"
  },
  "fa fa-comment-o": {
    "value": "far fa-comment",
    "library": "fa-regular"
  },
  "fa fa-commenting": {
    "value": "fas fa-comment-dots",
    "library": "fa-solid"
  },
  "fa fa-commenting-o": {
    "value": "far fa-comment-dots",
    "library": "fa-regular"
  },
  "fa fa-comments-o": {
    "value": "far fa-comments",
    "library": "fa-regular"
  },
  "fa fa-compass": {
    "value": "far fa-compass",
    "library": "fa-regular"
  },
  "fa fa-connectdevelop": {
    "value": "fab fa-connectdevelop",
    "library": "fa-brands"
  },
  "fa fa-contao": {
    "value": "fab fa-contao",
    "library": "fa-brands"
  },
  "fa fa-copyright": {
    "value": "far fa-copyright",
    "library": "fa-regular"
  },
  "fa fa-creative-commons": {
    "value": "fab fa-creative-commons",
    "library": "fa-brands"
  },
  "fa fa-credit-card": {
    "value": "far fa-credit-card",
    "library": "fa-regular"
  },
  "fa fa-credit-card-alt": {
    "value": "fas fa-credit-card",
    "library": "fa-solid"
  },
  "fa fa-css3": {
    "value": "fab fa-css3",
    "library": "fa-brands"
  },
  "fa fa-cutlery": {
    "value": "fas fa-utensils",
    "library": "fa-solid"
  },
  "fa fa-dashboard": {
    "value": "fas fa-tachometer-alt",
    "library": "fa-solid"
  },
  "fa fa-dashcube": {
    "value": "fab fa-dashcube",
    "library": "fa-brands"
  },
  "fa fa-deafness": {
    "value": "fas fa-deaf",
    "library": "fa-solid"
  },
  "fa fa-dedent": {
    "value": "fas fa-outdent",
    "library": "fa-solid"
  },
  "fa fa-delicious": {
    "value": "fab fa-delicious",
    "library": "fa-brands"
  },
  "fa fa-deviantart": {
    "value": "fab fa-deviantart",
    "library": "fa-brands"
  },
  "fa fa-diamond": {
    "value": "far fa-gem",
    "library": "fa-regular"
  },
  "fa fa-digg": {
    "value": "fab fa-digg",
    "library": "fa-brands"
  },
  "fa fa-dollar": {
    "value": "fas fa-dollar-sign",
    "library": "fa-solid"
  },
  "fa fa-dot-circle-o": {
    "value": "far fa-dot-circle",
    "library": "fa-regular"
  },
  "fa fa-dribbble": {
    "value": "fab fa-dribbble",
    "library": "fa-brands"
  },
  "fa fa-drivers-license": {
    "value": "fas fa-id-card",
    "library": "fa-solid"
  },
  "fa fa-drivers-license-o": {
    "value": "far fa-id-card",
    "library": "fa-regular"
  },
  "fa fa-dropbox": {
    "value": "fab fa-dropbox",
    "library": "fa-brands"
  },
  "fa fa-drupal": {
    "value": "fab fa-drupal",
    "library": "fa-brands"
  },
  "fa fa-edge": {
    "value": "fab fa-edge",
    "library": "fa-brands"
  },
  "fa fa-eercast": {
    "value": "fab fa-sellcast",
    "library": "fa-brands"
  },
  "fa fa-empire": {
    "value": "fab fa-empire",
    "library": "fa-brands"
  },
  "fa fa-envelope-o": {
    "value": "far fa-envelope",
    "library": "fa-regular"
  },
  "fa fa-envelope-open-o": {
    "value": "far fa-envelope-open",
    "library": "fa-regular"
  },
  "fa fa-envira": {
    "value": "fab fa-envira",
    "library": "fa-brands"
  },
  "fa fa-etsy": {
    "value": "fab fa-etsy",
    "library": "fa-brands"
  },
  "fa fa-eur": {
    "value": "fas fa-euro-sign",
    "library": "fa-solid"
  },
  "fa fa-euro": {
    "value": "fas fa-euro-sign",
    "library": "fa-solid"
  },
  "fa fa-exchange": {
    "value": "fas fa-exchange-alt",
    "library": "fa-solid"
  },
  "fa fa-expeditedssl": {
    "value": "fab fa-expeditedssl",
    "library": "fa-brands"
  },
  "fa fa-external-link": {
    "value": "fas fa-external-link-alt",
    "library": "fa-solid"
  },
  "fa fa-external-link-square": {
    "value": "fas fa-external-link-square-alt",
    "library": "fa-solid"
  },
  "fa fa-eye": {
    "value": "far fa-eye",
    "library": "fa-regular"
  },
  "fa fa-eye-slash": {
    "value": "far fa-eye-slash",
    "library": "fa-regular"
  },
  "fa fa-eyedropper": {
    "value": "fas fa-eye-dropper",
    "library": "fa-solid"
  },
  "fa fa-fa": {
    "value": "fab fa-font-awesome",
    "library": "fa-brands"
  },
  "fa fa-facebook": {
    "value": "fab fa-facebook-f",
    "library": "fa-brands"
  },
  "fa fa-facebook-f": {
    "value": "fab fa-facebook-f",
    "library": "fa-brands"
  },
  "fa fa-facebook-official": {
    "value": "fab fa-facebook",
    "library": "fa-brands"
  },
  "fa fa-facebook-square": {
    "value": "fab fa-facebook-square",
    "library": "fa-brands"
  },
  "fa fa-feed": {
    "value": "fas fa-rss",
    "library": "fa-solid"
  },
  "fa fa-file-archive-o": {
    "value": "far fa-file-archive",
    "library": "fa-regular"
  },
  "fa fa-file-audio-o": {
    "value": "far fa-file-audio",
    "library": "fa-regular"
  },
  "fa fa-file-code-o": {
    "value": "far fa-file-code",
    "library": "fa-regular"
  },
  "fa fa-file-excel-o": {
    "value": "far fa-file-excel",
    "library": "fa-regular"
  },
  "fa fa-file-image-o": {
    "value": "far fa-file-image",
    "library": "fa-regular"
  },
  "fa fa-file-movie-o": {
    "value": "far fa-file-video",
    "library": "fa-regular"
  },
  "fa fa-file-o": {
    "value": "far fa-file",
    "library": "fa-regular"
  },
  "fa fa-file-pdf-o": {
    "value": "far fa-file-pdf",
    "library": "fa-regular"
  },
  "fa fa-file-photo-o": {
    "value": "far fa-file-image",
    "library": "fa-regular"
  },
  "fa fa-file-picture-o": {
    "value": "far fa-file-image",
    "library": "fa-regular"
  },
  "fa fa-file-powerpoint-o": {
    "value": "far fa-file-powerpoint",
    "library": "fa-regular"
  },
  "fa fa-file-sound-o": {
    "value": "far fa-file-audio",
    "library": "fa-regular"
  },
  "fa fa-file-text": {
    "value": "fas fa-file-alt",
    "library": "fa-solid"
  },
  "fa fa-file-text-o": {
    "value": "far fa-file-alt",
    "library": "fa-regular"
  },
  "fa fa-file-video-o": {
    "value": "far fa-file-video",
    "library": "fa-regular"
  },
  "fa fa-file-word-o": {
    "value": "far fa-file-word",
    "library": "fa-regular"
  },
  "fa fa-file-zip-o": {
    "value": "far fa-file-archive",
    "library": "fa-regular"
  },
  "fa fa-files-o": {
    "value": "far fa-copy",
    "library": "fa-regular"
  },
  "fa fa-firefox": {
    "value": "fab fa-firefox",
    "library": "fa-brands"
  },
  "fa fa-first-order": {
    "value": "fab fa-first-order",
    "library": "fa-brands"
  },
  "fa fa-flag-o": {
    "value": "far fa-flag",
    "library": "fa-regular"
  },
  "fa fa-flash": {
    "value": "fas fa-bolt",
    "library": "fa-solid"
  },
  "fa fa-flickr": {
    "value": "fab fa-flickr",
    "library": "fa-brands"
  },
  "fa fa-floppy-o": {
    "value": "far fa-save",
    "library": "fa-regular"
  },
  "fa fa-folder-o": {
    "value": "far fa-folder",
    "library": "fa-regular"
  },
  "fa fa-folder-open-o": {
    "value": "far fa-folder-open",
    "library": "fa-regular"
  },
  "fa fa-font-awesome": {
    "value": "fab fa-font-awesome",
    "library": "fa-brands"
  },
  "fa fa-fonticons": {
    "value": "fab fa-fonticons",
    "library": "fa-brands"
  },
  "fa fa-fort-awesome": {
    "value": "fab fa-fort-awesome",
    "library": "fa-brands"
  },
  "fa fa-forumbee": {
    "value": "fab fa-forumbee",
    "library": "fa-brands"
  },
  "fa fa-foursquare": {
    "value": "fab fa-foursquare",
    "library": "fa-brands"
  },
  "fa fa-free-code-camp": {
    "value": "fab fa-free-code-camp",
    "library": "fa-brands"
  },
  "fa fa-frown-o": {
    "value": "far fa-frown",
    "library": "fa-regular"
  },
  "fa fa-futbol-o": {
    "value": "far fa-futbol",
    "library": "fa-regular"
  },
  "fa fa-gbp": {
    "value": "fas fa-pound-sign",
    "library": "fa-solid"
  },
  "fa fa-ge": {
    "value": "fab fa-empire",
    "library": "fa-brands"
  },
  "fa fa-gear": {
    "value": "fas fa-cog",
    "library": "fa-solid"
  },
  "fa fa-gears": {
    "value": "fas fa-cogs",
    "library": "fa-solid"
  },
  "fa fa-get-pocket": {
    "value": "fab fa-get-pocket",
    "library": "fa-brands"
  },
  "fa fa-gg": {
    "value": "fab fa-gg",
    "library": "fa-brands"
  },
  "fa fa-gg-circle": {
    "value": "fab fa-gg-circle",
    "library": "fa-brands"
  },
  "fa fa-git": {
    "value": "fab fa-git",
    "library": "fa-brands"
  },
  "fa fa-git-square": {
    "value": "fab fa-git-square",
    "library": "fa-brands"
  },
  "fa fa-github": {
    "value": "fab fa-github",
    "library": "fa-brands"
  },
  "fa fa-github-alt": {
    "value": "fab fa-github-alt",
    "library": "fa-brands"
  },
  "fa fa-github-square": {
    "value": "fab fa-github-square",
    "library": "fa-brands"
  },
  "fa fa-gitlab": {
    "value": "fab fa-gitlab",
    "library": "fa-brands"
  },
  "fa fa-gittip": {
    "value": "fab fa-gratipay",
    "library": "fa-brands"
  },
  "fa fa-glass": {
    "value": "fas fa-glass-martini",
    "library": "fa-solid"
  },
  "fa fa-glide": {
    "value": "fab fa-glide",
    "library": "fa-brands"
  },
  "fa fa-glide-g": {
    "value": "fab fa-glide-g",
    "library": "fa-brands"
  },
  "fa fa-google": {
    "value": "fab fa-google",
    "library": "fa-brands"
  },
  "fa fa-google-plus": {
    "value": "fab fa-google-plus-g",
    "library": "fa-brands"
  },
  "fa fa-google-plus-circle": {
    "value": "fab fa-google-plus",
    "library": "fa-brands"
  },
  "fa fa-google-plus-official": {
    "value": "fab fa-google-plus",
    "library": "fa-brands"
  },
  "fa fa-google-plus-square": {
    "value": "fab fa-google-plus-square",
    "library": "fa-brands"
  },
  "fa fa-google-wallet": {
    "value": "fab fa-google-wallet",
    "library": "fa-brands"
  },
  "fa fa-gratipay": {
    "value": "fab fa-gratipay",
    "library": "fa-brands"
  },
  "fa fa-grav": {
    "value": "fab fa-grav",
    "library": "fa-brands"
  },
  "fa fa-group": {
    "value": "fas fa-users",
    "library": "fa-solid"
  },
  "fa fa-hacker-news": {
    "value": "fab fa-hacker-news",
    "library": "fa-brands"
  },
  "fa fa-hand-grab-o": {
    "value": "far fa-hand-rock",
    "library": "fa-regular"
  },
  "fa fa-hand-lizard-o": {
    "value": "far fa-hand-lizard",
    "library": "fa-regular"
  },
  "fa fa-hand-o-down": {
    "value": "far fa-hand-point-down",
    "library": "fa-regular"
  },
  "fa fa-hand-o-left": {
    "value": "far fa-hand-point-left",
    "library": "fa-regular"
  },
  "fa fa-hand-o-right": {
    "value": "far fa-hand-point-right",
    "library": "fa-regular"
  },
  "fa fa-hand-o-up": {
    "value": "far fa-hand-point-up",
    "library": "fa-regular"
  },
  "fa fa-hand-paper-o": {
    "value": "far fa-hand-paper",
    "library": "fa-regular"
  },
  "fa fa-hand-peace-o": {
    "value": "far fa-hand-peace",
    "library": "fa-regular"
  },
  "fa fa-hand-pointer-o": {
    "value": "far fa-hand-pointer",
    "library": "fa-regular"
  },
  "fa fa-hand-rock-o": {
    "value": "far fa-hand-rock",
    "library": "fa-regular"
  },
  "fa fa-hand-scissors-o": {
    "value": "far fa-hand-scissors",
    "library": "fa-regular"
  },
  "fa fa-hand-spock-o": {
    "value": "far fa-hand-spock",
    "library": "fa-regular"
  },
  "fa fa-hand-stop-o": {
    "value": "far fa-hand-paper",
    "library": "fa-regular"
  },
  "fa fa-handshake-o": {
    "value": "far fa-handshake",
    "library": "fa-regular"
  },
  "fa fa-hard-of-hearing": {
    "value": "fas fa-deaf",
    "library": "fa-solid"
  },
  "fa fa-hdd-o": {
    "value": "far fa-hdd",
    "library": "fa-regular"
  },
  "fa fa-header": {
    "value": "fas fa-heading",
    "library": "fa-solid"
  },
  "fa fa-heart-o": {
    "value": "far fa-heart",
    "library": "fa-regular"
  },
  "fa fa-hospital-o": {
    "value": "far fa-hospital",
    "library": "fa-regular"
  },
  "fa fa-hotel": {
    "value": "fas fa-bed",
    "library": "fa-solid"
  },
  "fa fa-hourglass-1": {
    "value": "fas fa-hourglass-start",
    "library": "fa-solid"
  },
  "fa fa-hourglass-2": {
    "value": "fas fa-hourglass-half",
    "library": "fa-solid"
  },
  "fa fa-hourglass-3": {
    "value": "fas fa-hourglass-end",
    "library": "fa-solid"
  },
  "fa fa-hourglass-o": {
    "value": "far fa-hourglass",
    "library": "fa-regular"
  },
  "fa fa-houzz": {
    "value": "fab fa-houzz",
    "library": "fa-brands"
  },
  "fa fa-html5": {
    "value": "fab fa-html5",
    "library": "fa-brands"
  },
  "fa fa-id-badge": {
    "value": "far fa-id-badge",
    "library": "fa-regular"
  },
  "fa fa-id-card-o": {
    "value": "far fa-id-card",
    "library": "fa-regular"
  },
  "fa fa-ils": {
    "value": "fas fa-shekel-sign",
    "library": "fa-solid"
  },
  "fa fa-image": {
    "value": "far fa-image",
    "library": "fa-regular"
  },
  "fa fa-imdb": {
    "value": "fab fa-imdb",
    "library": "fa-brands"
  },
  "fa fa-inr": {
    "value": "fas fa-rupee-sign",
    "library": "fa-solid"
  },
  "fa fa-instagram": {
    "value": "fab fa-instagram",
    "library": "fa-brands"
  },
  "fa fa-institution": {
    "value": "fas fa-university",
    "library": "fa-solid"
  },
  "fa fa-internet-explorer": {
    "value": "fab fa-internet-explorer",
    "library": "fa-brands"
  },
  "fa fa-intersex": {
    "value": "fas fa-transgender",
    "library": "fa-solid"
  },
  "fa fa-ioxhost": {
    "value": "fab fa-ioxhost",
    "library": "fa-brands"
  },
  "fa fa-joomla": {
    "value": "fab fa-joomla",
    "library": "fa-brands"
  },
  "fa fa-jpy": {
    "value": "fas fa-yen-sign",
    "library": "fa-solid"
  },
  "fa fa-jsfiddle": {
    "value": "fab fa-jsfiddle",
    "library": "fa-brands"
  },
  "fa fa-keyboard-o": {
    "value": "far fa-keyboard",
    "library": "fa-regular"
  },
  "fa fa-krw": {
    "value": "fas fa-won-sign",
    "library": "fa-solid"
  },
  "fa fa-lastfm": {
    "value": "fab fa-lastfm",
    "library": "fa-brands"
  },
  "fa fa-lastfm-square": {
    "value": "fab fa-lastfm-square",
    "library": "fa-brands"
  },
  "fa fa-leanpub": {
    "value": "fab fa-leanpub",
    "library": "fa-brands"
  },
  "fa fa-legal": {
    "value": "fas fa-gavel",
    "library": "fa-solid"
  },
  "fa fa-lemon-o": {
    "value": "far fa-lemon",
    "library": "fa-regular"
  },
  "fa fa-level-down": {
    "value": "fas fa-level-down-alt",
    "library": "fa-solid"
  },
  "fa fa-level-up": {
    "value": "fas fa-level-up-alt",
    "library": "fa-solid"
  },
  "fa fa-life-bouy": {
    "value": "far fa-life-ring",
    "library": "fa-regular"
  },
  "fa fa-life-buoy": {
    "value": "far fa-life-ring",
    "library": "fa-regular"
  },
  "fa fa-life-ring": {
    "value": "far fa-life-ring",
    "library": "fa-regular"
  },
  "fa fa-life-saver": {
    "value": "far fa-life-ring",
    "library": "fa-regular"
  },
  "fa fa-lightbulb-o": {
    "value": "far fa-lightbulb",
    "library": "fa-regular"
  },
  "fa fa-line-chart": {
    "value": "fas fa-chart-line",
    "library": "fa-solid"
  },
  "fa fa-linkedin": {
    "value": "fab fa-linkedin-in",
    "library": "fa-brands"
  },
  "fa fa-linkedin-square": {
    "value": "fab fa-linkedin",
    "library": "fa-brands"
  },
  "fa fa-linode": {
    "value": "fab fa-linode",
    "library": "fa-brands"
  },
  "fa fa-linux": {
    "value": "fab fa-linux",
    "library": "fa-brands"
  },
  "fa fa-list-alt": {
    "value": "far fa-list-alt",
    "library": "fa-regular"
  },
  "fa fa-long-arrow-down": {
    "value": "fas fa-long-arrow-alt-down",
    "library": "fa-solid"
  },
  "fa fa-long-arrow-left": {
    "value": "fas fa-long-arrow-alt-left",
    "library": "fa-solid"
  },
  "fa fa-long-arrow-right": {
    "value": "fas fa-long-arrow-alt-right",
    "library": "fa-solid"
  },
  "fa fa-long-arrow-up": {
    "value": "fas fa-long-arrow-alt-up",
    "library": "fa-solid"
  },
  "fa fa-mail-forward": {
    "value": "fas fa-share",
    "library": "fa-solid"
  },
  "fa fa-mail-reply": {
    "value": "fas fa-reply",
    "library": "fa-solid"
  },
  "fa fa-mail-reply-all": {
    "value": "fas fa-reply-all",
    "library": "fa-solid"
  },
  "fa fa-map-marker": {
    "value": "fas fa-map-marker-alt",
    "library": "fa-solid"
  },
  "fa fa-map-o": {
    "value": "far fa-map",
    "library": "fa-regular"
  },
  "fa fa-maxcdn": {
    "value": "fab fa-maxcdn",
    "library": "fa-brands"
  },
  "fa fa-meanpath": {
    "value": "fab fa-font-awesome",
    "library": "fa-brands"
  },
  "fa fa-medium": {
    "value": "fab fa-medium",
    "library": "fa-brands"
  },
  "fa fa-meetup": {
    "value": "fab fa-meetup",
    "library": "fa-brands"
  },
  "fa fa-meh-o": {
    "value": "far fa-meh",
    "library": "fa-regular"
  },
  "fa fa-minus-square-o": {
    "value": "far fa-minus-square",
    "library": "fa-regular"
  },
  "fa fa-mixcloud": {
    "value": "fab fa-mixcloud",
    "library": "fa-brands"
  },
  "fa fa-mobile": {
    "value": "fas fa-mobile-alt",
    "library": "fa-solid"
  },
  "fa fa-mobile-phone": {
    "value": "fas fa-mobile-alt",
    "library": "fa-solid"
  },
  "fa fa-modx": {
    "value": "fab fa-modx",
    "library": "fa-brands"
  },
  "fa fa-money": {
    "value": "far fa-money-bill-alt",
    "library": "fa-regular"
  },
  "fa fa-moon-o": {
    "value": "far fa-moon",
    "library": "fa-regular"
  },
  "fa fa-mortar-board": {
    "value": "fas fa-graduation-cap",
    "library": "fa-solid"
  },
  "fa fa-navicon": {
    "value": "fas fa-bars",
    "library": "fa-solid"
  },
  "fa fa-newspaper-o": {
    "value": "far fa-newspaper",
    "library": "fa-regular"
  },
  "fa fa-object-group": {
    "value": "far fa-object-group",
    "library": "fa-regular"
  },
  "fa fa-object-ungroup": {
    "value": "far fa-object-ungroup",
    "library": "fa-regular"
  },
  "fa fa-odnoklassniki": {
    "value": "fab fa-odnoklassniki",
    "library": "fa-brands"
  },
  "fa fa-odnoklassniki-square": {
    "value": "fab fa-odnoklassniki-square",
    "library": "fa-brands"
  },
  "fa fa-opencart": {
    "value": "fab fa-opencart",
    "library": "fa-brands"
  },
  "fa fa-openid": {
    "value": "fab fa-openid",
    "library": "fa-brands"
  },
  "fa fa-opera": {
    "value": "fab fa-opera",
    "library": "fa-brands"
  },
  "fa fa-optin-monster": {
    "value": "fab fa-optin-monster",
    "library": "fa-brands"
  },
  "fa fa-pagelines": {
    "value": "fab fa-pagelines",
    "library": "fa-brands"
  },
  "fa fa-paper-plane-o": {
    "value": "far fa-paper-plane",
    "library": "fa-regular"
  },
  "fa fa-paste": {
    "value": "far fa-clipboard",
    "library": "fa-regular"
  },
  "fa fa-pause-circle-o": {
    "value": "far fa-pause-circle",
    "library": "fa-regular"
  },
  "fa fa-paypal": {
    "value": "fab fa-paypal",
    "library": "fa-brands"
  },
  "fa fa-pencil": {
    "value": "fas fa-pencil-alt",
    "library": "fa-solid"
  },
  "fa fa-pencil-square": {
    "value": "fas fa-pen-square",
    "library": "fa-solid"
  },
  "fa fa-pencil-square-o": {
    "value": "far fa-edit",
    "library": "fa-regular"
  },
  "fa fa-photo": {
    "value": "far fa-image",
    "library": "fa-regular"
  },
  "fa fa-picture-o": {
    "value": "far fa-image",
    "library": "fa-regular"
  },
  "fa fa-pie-chart": {
    "value": "fas fa-chart-pie",
    "library": "fa-solid"
  },
  "fa fa-pied-piper": {
    "value": "fab fa-pied-piper",
    "library": "fa-brands"
  },
  "fa fa-pied-piper-alt": {
    "value": "fab fa-pied-piper-alt",
    "library": "fa-brands"
  },
  "fa fa-pied-piper-pp": {
    "value": "fab fa-pied-piper-pp",
    "library": "fa-brands"
  },
  "fa fa-pinterest": {
    "value": "fab fa-pinterest",
    "library": "fa-brands"
  },
  "fa fa-pinterest-p": {
    "value": "fab fa-pinterest-p",
    "library": "fa-brands"
  },
  "fa fa-pinterest-square": {
    "value": "fab fa-pinterest-square",
    "library": "fa-brands"
  },
  "fa fa-play-circle-o": {
    "value": "far fa-play-circle",
    "library": "fa-regular"
  },
  "fa fa-plus-square-o": {
    "value": "far fa-plus-square",
    "library": "fa-regular"
  },
  "fa fa-product-hunt": {
    "value": "fab fa-product-hunt",
    "library": "fa-brands"
  },
  "fa fa-qq": {
    "value": "fab fa-qq",
    "library": "fa-brands"
  },
  "fa fa-question-circle-o": {
    "value": "far fa-question-circle",
    "library": "fa-regular"
  },
  "fa fa-quora": {
    "value": "fab fa-quora",
    "library": "fa-brands"
  },
  "fa fa-ra": {
    "value": "fab fa-rebel",
    "library": "fa-brands"
  },
  "fa fa-ravelry": {
    "value": "fab fa-ravelry",
    "library": "fa-brands"
  },
  "fa fa-rebel": {
    "value": "fab fa-rebel",
    "library": "fa-brands"
  },
  "fa fa-reddit": {
    "value": "fab fa-reddit",
    "library": "fa-brands"
  },
  "fa fa-reddit-alien": {
    "value": "fab fa-reddit-alien",
    "library": "fa-brands"
  },
  "fa fa-reddit-square": {
    "value": "fab fa-reddit-square",
    "library": "fa-brands"
  },
  "fa fa-refresh": {
    "value": "fas fa-sync",
    "library": "fa-solid"
  },
  "fa fa-registered": {
    "value": "far fa-registered",
    "library": "fa-regular"
  },
  "fa fa-remove": {
    "value": "fas fa-times",
    "library": "fa-solid"
  },
  "fa fa-renren": {
    "value": "fab fa-renren",
    "library": "fa-brands"
  },
  "fa fa-reorder": {
    "value": "fas fa-bars",
    "library": "fa-solid"
  },
  "fa fa-repeat": {
    "value": "fas fa-redo",
    "library": "fa-solid"
  },
  "fa fa-resistance": {
    "value": "fab fa-rebel",
    "library": "fa-brands"
  },
  "fa fa-rmb": {
    "value": "fas fa-yen-sign",
    "library": "fa-solid"
  },
  "fa fa-rotate-left": {
    "value": "fas fa-undo",
    "library": "fa-solid"
  },
  "fa fa-rotate-right": {
    "value": "fas fa-redo",
    "library": "fa-solid"
  },
  "fa fa-rouble": {
    "value": "fas fa-ruble-sign",
    "library": "fa-solid"
  },
  "fa fa-rub": {
    "value": "fas fa-ruble-sign",
    "library": "fa-solid"
  },
  "fa fa-ruble": {
    "value": "fas fa-ruble-sign",
    "library": "fa-solid"
  },
  "fa fa-rupee": {
    "value": "fas fa-rupee-sign",
    "library": "fa-solid"
  },
  "fa fa-s15": {
    "value": "fas fa-bath",
    "library": "fa-solid"
  },
  "fa fa-safari": {
    "value": "fab fa-safari",
    "library": "fa-brands"
  },
  "fa fa-scissors": {
    "value": "fas fa-cut",
    "library": "fa-solid"
  },
  "fa fa-scribd": {
    "value": "fab fa-scribd",
    "library": "fa-brands"
  },
  "fa fa-sellsy": {
    "value": "fab fa-sellsy",
    "library": "fa-brands"
  },
  "fa fa-send": {
    "value": "fas fa-paper-plane",
    "library": "fa-solid"
  },
  "fa fa-send-o": {
    "value": "far fa-paper-plane",
    "library": "fa-regular"
  },
  "fa fa-share-square-o": {
    "value": "far fa-share-square",
    "library": "fa-regular"
  },
  "fa fa-shekel": {
    "value": "fas fa-shekel-sign",
    "library": "fa-solid"
  },
  "fa fa-sheqel": {
    "value": "fas fa-shekel-sign",
    "library": "fa-solid"
  },
  "fa fa-shield": {
    "value": "fas fa-shield-alt",
    "library": "fa-solid"
  },
  "fa fa-shirtsinbulk": {
    "value": "fab fa-shirtsinbulk",
    "library": "fa-brands"
  },
  "fa fa-sign-in": {
    "value": "fas fa-sign-in-alt",
    "library": "fa-solid"
  },
  "fa fa-sign-out": {
    "value": "fas fa-sign-out-alt",
    "library": "fa-solid"
  },
  "fa fa-signing": {
    "value": "fas fa-sign-language",
    "library": "fa-solid"
  },
  "fa fa-simplybuilt": {
    "value": "fab fa-simplybuilt",
    "library": "fa-brands"
  },
  "fa fa-skyatlas": {
    "value": "fab fa-skyatlas",
    "library": "fa-brands"
  },
  "fa fa-skype": {
    "value": "fab fa-skype",
    "library": "fa-brands"
  },
  "fa fa-slack": {
    "value": "fab fa-slack",
    "library": "fa-brands"
  },
  "fa fa-sliders": {
    "value": "fas fa-sliders-h",
    "library": "fa-solid"
  },
  "fa fa-slideshare": {
    "value": "fab fa-slideshare",
    "library": "fa-brands"
  },
  "fa fa-smile-o": {
    "value": "far fa-smile",
    "library": "fa-regular"
  },
  "fa fa-snapchat": {
    "value": "fab fa-snapchat",
    "library": "fa-brands"
  },
  "fa fa-snapchat-ghost": {
    "value": "fab fa-snapchat-ghost",
    "library": "fa-brands"
  },
  "fa fa-snapchat-square": {
    "value": "fab fa-snapchat-square",
    "library": "fa-brands"
  },
  "fa fa-snowflake-o": {
    "value": "far fa-snowflake",
    "library": "fa-regular"
  },
  "fa fa-soccer-ball-o": {
    "value": "far fa-futbol",
    "library": "fa-regular"
  },
  "fa fa-sort-alpha-asc": {
    "value": "fas fa-sort-alpha-down",
    "library": "fa-solid"
  },
  "fa fa-sort-alpha-desc": {
    "value": "fas fa-sort-alpha-up",
    "library": "fa-solid"
  },
  "fa fa-sort-amount-asc": {
    "value": "fas fa-sort-amount-down",
    "library": "fa-solid"
  },
  "fa fa-sort-amount-desc": {
    "value": "fas fa-sort-amount-up",
    "library": "fa-solid"
  },
  "fa fa-sort-asc": {
    "value": "fas fa-sort-up",
    "library": "fa-solid"
  },
  "fa fa-sort-desc": {
    "value": "fas fa-sort-down",
    "library": "fa-solid"
  },
  "fa fa-sort-numeric-asc": {
    "value": "fas fa-sort-numeric-down",
    "library": "fa-solid"
  },
  "fa fa-sort-numeric-desc": {
    "value": "fas fa-sort-numeric-up",
    "library": "fa-solid"
  },
  "fa fa-soundcloud": {
    "value": "fab fa-soundcloud",
    "library": "fa-brands"
  },
  "fa fa-spoon": {
    "value": "fas fa-utensil-spoon",
    "library": "fa-solid"
  },
  "fa fa-spotify": {
    "value": "fab fa-spotify",
    "library": "fa-brands"
  },
  "fa fa-square-o": {
    "value": "far fa-square",
    "library": "fa-regular"
  },
  "fa fa-stack-exchange": {
    "value": "fab fa-stack-exchange",
    "library": "fa-brands"
  },
  "fa fa-stack-overflow": {
    "value": "fab fa-stack-overflow",
    "library": "fa-brands"
  },
  "fa fa-star-half-empty": {
    "value": "far fa-star-half",
    "library": "fa-regular"
  },
  "fa fa-star-half-full": {
    "value": "far fa-star-half",
    "library": "fa-regular"
  },
  "fa fa-star-half-o": {
    "value": "far fa-star-half",
    "library": "fa-regular"
  },
  "fa fa-star-o": {
    "value": "far fa-star",
    "library": "fa-regular"
  },
  "fa fa-steam": {
    "value": "fab fa-steam",
    "library": "fa-brands"
  },
  "fa fa-steam-square": {
    "value": "fab fa-steam-square",
    "library": "fa-brands"
  },
  "fa fa-sticky-note-o": {
    "value": "far fa-sticky-note",
    "library": "fa-regular"
  },
  "fa fa-stop-circle-o": {
    "value": "far fa-stop-circle",
    "library": "fa-regular"
  },
  "fa fa-stumbleupon": {
    "value": "fab fa-stumbleupon",
    "library": "fa-brands"
  },
  "fa fa-stumbleupon-circle": {
    "value": "fab fa-stumbleupon-circle",
    "library": "fa-brands"
  },
  "fa fa-sun-o": {
    "value": "far fa-sun",
    "library": "fa-regular"
  },
  "fa fa-superpowers": {
    "value": "fab fa-superpowers",
    "library": "fa-brands"
  },
  "fa fa-support": {
    "value": "far fa-life-ring",
    "library": "fa-regular"
  },
  "fa fa-tablet": {
    "value": "fas fa-tablet-alt",
    "library": "fa-solid"
  },
  "fa fa-tachometer": {
    "value": "fas fa-tachometer-alt",
    "library": "fa-solid"
  },
  "fa fa-telegram": {
    "value": "fab fa-telegram",
    "library": "fa-brands"
  },
  "fa fa-television": {
    "value": "fas fa-tv",
    "library": "fa-solid"
  },
  "fa fa-tencent-weibo": {
    "value": "fab fa-tencent-weibo",
    "library": "fa-brands"
  },
  "fa fa-themeisle": {
    "value": "fab fa-themeisle",
    "library": "fa-brands"
  },
  "fa fa-thermometer": {
    "value": "fas fa-thermometer-full",
    "library": "fa-solid"
  },
  "fa fa-thermometer-0": {
    "value": "fas fa-thermometer-empty",
    "library": "fa-solid"
  },
  "fa fa-thermometer-1": {
    "value": "fas fa-thermometer-quarter",
    "library": "fa-solid"
  },
  "fa fa-thermometer-2": {
    "value": "fas fa-thermometer-half",
    "library": "fa-solid"
  },
  "fa fa-thermometer-3": {
    "value": "fas fa-thermometer-three-quarters",
    "library": "fa-solid"
  },
  "fa fa-thermometer-4": {
    "value": "fas fa-thermometer-full",
    "library": "fa-solid"
  },
  "fa fa-thumb-tack": {
    "value": "fas fa-thumbtack",
    "library": "fa-solid"
  },
  "fa fa-thumbs-o-down": {
    "value": "far fa-thumbs-down",
    "library": "fa-regular"
  },
  "fa fa-thumbs-o-up": {
    "value": "far fa-thumbs-up",
    "library": "fa-regular"
  },
  "fa fa-ticket": {
    "value": "fas fa-ticket-alt",
    "library": "fa-solid"
  },
  "fa fa-times-circle-o": {
    "value": "far fa-times-circle",
    "library": "fa-regular"
  },
  "fa fa-times-rectangle": {
    "value": "fas fa-window-close",
    "library": "fa-solid"
  },
  "fa fa-times-rectangle-o": {
    "value": "far fa-window-close",
    "library": "fa-regular"
  },
  "fa fa-toggle-down": {
    "value": "far fa-caret-square-down",
    "library": "fa-regular"
  },
  "fa fa-toggle-left": {
    "value": "far fa-caret-square-left",
    "library": "fa-regular"
  },
  "fa fa-toggle-right": {
    "value": "far fa-caret-square-right",
    "library": "fa-regular"
  },
  "fa fa-toggle-up": {
    "value": "far fa-caret-square-up",
    "library": "fa-regular"
  },
  "fa fa-trash": {
    "value": "fas fa-trash-alt",
    "library": "fa-solid"
  },
  "fa fa-trash-o": {
    "value": "far fa-trash-alt",
    "library": "fa-regular"
  },
  "fa fa-trello": {
    "value": "fab fa-trello",
    "library": "fa-brands"
  },
  "fa fa-tripadvisor": {
    "value": "fab fa-tripadvisor",
    "library": "fa-brands"
  },
  "fa fa-try": {
    "value": "fas fa-lira-sign",
    "library": "fa-solid"
  },
  "fa fa-tumblr": {
    "value": "fab fa-tumblr",
    "library": "fa-brands"
  },
  "fa fa-tumblr-square": {
    "value": "fab fa-tumblr-square",
    "library": "fa-brands"
  },
  "fa fa-turkish-lira": {
    "value": "fas fa-lira-sign",
    "library": "fa-solid"
  },
  "fa fa-twitch": {
    "value": "fab fa-twitch",
    "library": "fa-brands"
  },
  "fa fa-twitter": {
    "value": "fab fa-twitter",
    "library": "fa-brands"
  },
  "fa fa-twitter-square": {
    "value": "fab fa-twitter-square",
    "library": "fa-brands"
  },
  "fa fa-unsorted": {
    "value": "fas fa-sort",
    "library": "fa-solid"
  },
  "fa fa-usb": {
    "value": "fab fa-usb",
    "library": "fa-brands"
  },
  "fa fa-usd": {
    "value": "fas fa-dollar-sign",
    "library": "fa-solid"
  },
  "fa fa-user-circle-o": {
    "value": "far fa-user-circle",
    "library": "fa-regular"
  },
  "fa fa-user-o": {
    "value": "far fa-user",
    "library": "fa-regular"
  },
  "fa fa-vcard": {
    "value": "fas fa-address-card",
    "library": "fa-solid"
  },
  "fa fa-vcard-o": {
    "value": "far fa-address-card",
    "library": "fa-regular"
  },
  "fa fa-viacoin": {
    "value": "fab fa-viacoin",
    "library": "fa-brands"
  },
  "fa fa-viadeo": {
    "value": "fab fa-viadeo",
    "library": "fa-brands"
  },
  "fa fa-viadeo-square": {
    "value": "fab fa-viadeo-square",
    "library": "fa-brands"
  },
  "fa fa-video-camera": {
    "value": "fas fa-video",
    "library": "fa-solid"
  },
  "fa fa-vimeo": {
    "value": "fab fa-vimeo-v",
    "library": "fa-brands"
  },
  "fa fa-vimeo-square": {
    "value": "fab fa-vimeo-square",
    "library": "fa-brands"
  },
  "fa fa-vine": {
    "value": "fab fa-vine",
    "library": "fa-brands"
  },
  "fa fa-vk": {
    "value": "fab fa-vk",
    "library": "fa-brands"
  },
  "fa fa-volume-control-phone": {
    "value": "fas fa-phone-volume",
    "library": "fa-solid"
  },
  "fa fa-warning": {
    "value": "fas fa-exclamation-triangle",
    "library": "fa-solid"
  },
  "fa fa-wechat": {
    "value": "fab fa-weixin",
    "library": "fa-brands"
  },
  "fa fa-weibo": {
    "value": "fab fa-weibo",
    "library": "fa-brands"
  },
  "fa fa-weixin": {
    "value": "fab fa-weixin",
    "library": "fa-brands"
  },
  "fa fa-whatsapp": {
    "value": "fab fa-whatsapp",
    "library": "fa-brands"
  },
  "fa fa-wheelchair-alt": {
    "value": "fab fa-accessible-icon",
    "library": "fa-brands"
  },
  "fa fa-wikipedia-w": {
    "value": "fab fa-wikipedia-w",
    "library": "fa-brands"
  },
  "fa fa-window-close-o": {
    "value": "far fa-window-close",
    "library": "fa-regular"
  },
  "fa fa-window-maximize": {
    "value": "far fa-window-maximize",
    "library": "fa-regular"
  },
  "fa fa-window-restore": {
    "value": "far fa-window-restore",
    "library": "fa-regular"
  },
  "fa fa-windows": {
    "value": "fab fa-windows",
    "library": "fa-brands"
  },
  "fa fa-won": {
    "value": "fas fa-won-sign",
    "library": "fa-solid"
  },
  "fa fa-wordpress": {
    "value": "fab fa-wordpress",
    "library": "fa-brands"
  },
  "fa fa-wpbeginner": {
    "value": "fab fa-wpbeginner",
    "library": "fa-brands"
  },
  "fa fa-wpexplorer": {
    "value": "fab fa-wpexplorer",
    "library": "fa-brands"
  },
  "fa fa-wpforms": {
    "value": "fab fa-wpforms",
    "library": "fa-brands"
  },
  "fa fa-xing": {
    "value": "fab fa-xing",
    "library": "fa-brands"
  },
  "fa fa-xing-square": {
    "value": "fab fa-xing-square",
    "library": "fa-brands"
  },
  "fa fa-y-combinator": {
    "value": "fab fa-y-combinator",
    "library": "fa-brands"
  },
  "fa fa-y-combinator-square": {
    "value": "fab fa-hacker-news",
    "library": "fa-brands"
  },
  "fa fa-yahoo": {
    "value": "fab fa-yahoo",
    "library": "fa-brands"
  },
  "fa fa-yc": {
    "value": "fab fa-y-combinator",
    "library": "fa-brands"
  },
  "fa fa-yc-square": {
    "value": "fab fa-hacker-news",
    "library": "fa-brands"
  },
  "fa fa-yelp": {
    "value": "fab fa-yelp",
    "library": "fa-brands"
  },
  "fa fa-yen": {
    "value": "fas fa-yen-sign",
    "library": "fa-solid"
  },
  "fa fa-yoast": {
    "value": "fab fa-yoast",
    "library": "fa-brands"
  },
  "fa fa-youtube": {
    "value": "fab fa-youtube",
    "library": "fa-brands"
  },
  "fa fa-youtube-play": {
    "value": "fab fa-youtube",
    "library": "fa-brands"
  },
  "fa fa-youtube-square": {
    "value": "fab fa-youtube-square",
    "library": "fa-brands"
  }
}