!function(e){var t={};function n(o){if(t[o])return t[o].exports;var i=t[o]={i:o,l:!1,exports:{}};return e[o].call(i.exports,i,i.exports,n),i.l=!0,i.exports}n.m=e,n.c=t,n.d=function(e,t,o){n.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:o})},n.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},n.t=function(e,t){if(1&t&&(e=n(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var o=Object.create(null);if(n.r(o),Object.defineProperty(o,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var i in e)n.d(o,i,function(t){return e[t]}.bind(null,i));return o},n.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return n.d(t,"a",t),t},n.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},n.p="",n(n.s=123)}({119:function(e,t,n){},123:function(e,t,n){"use strict";n.r(t);var o=null,i=wp.media&&wp.media.View?wp.media.View.extend({tagName:"div",className:"attachments-browser envatoelements-attachments-browser",attribution:null,initialize:function(){_.defaults(this.options,{search:!1}),o=this,window.envatoElements.initPhotos(this.$el.get(0),this.photoUploadComplete)},photoUploadComplete:function(e){e&&e.attachment_data&&(o.model.frame.content.mode("browse"),o.model.get("selection").add(e.attachment_data),o.model.frame.trigger("library:selection:add"),o.model.get("selection"),jQuery(".media-frame .media-button-select").click())},dispose:function(){return wp.media.View.prototype.dispose.apply(this,arguments),this}}):null;n(119);"undefined"!=typeof jQuery&&function(e){if("undefined"!=typeof wp&&wp.media){var t=wp.media.view.MediaFrame.Post,n=wp.media.view.MediaFrame.Select;wp.media.view.MediaFrame.Post=t.extend({browseRouter(e){t.prototype.browseRouter.apply(this,arguments),e.set({envatoElements:{text:"Envato Elements",priority:60}})},bindHandlers(){t.prototype.bindHandlers.apply(this,arguments),this.on("content:create:envatoElements",this.envatoElementsContent,this)},envatoElementsContent(e){var t=this.state();this.$el.addClass("hide-toolbar"),e.view=new i({collection:t.get("envatoElements-images"),selection:t.get("envatoElements-selection"),controller:this,model:t,idealColumnWidth:t.get("idealColumnWidth"),suggestedWidth:t.get("suggestedWidth"),suggestedHeight:t.get("suggestedHeight")})},getFrame(e){return this.states.findWhere({id:e})}}),wp.media.view.MediaFrame.Select=n.extend({browseRouter(e){n.prototype.browseRouter.apply(this,arguments),e.set({envatoElements:{text:"Envato Elements",priority:60}})},bindHandlers(){n.prototype.bindHandlers.apply(this,arguments),this.on("content:create:envatoElements",this.envatoElementsContent,this)},envatoElementsContent(e){var t=this.state();t.get("provider")||t.set("provider",""),this.$el.addClass("hide-toolbar"),e.view=new i({collection:t.get("envatoElements-images"),selection:t.get("envatoElements-selection"),controller:this,model:t,idealColumnWidth:t.get("idealColumnWidth"),suggestedWidth:t.get("suggestedWidth"),suggestedHeight:t.get("suggestedHeight"),provider:t.get("provider")})},getFrame(e){return this.states.findWhere({id:e})}})}}(jQuery)}});