@font-face {
	font-family: 'ast-logo';
	src:    url('fonts/ast-logo.eot?476cfz');
	src:    url('fonts/ast-logo.eot?476cfz#iefix') format('embedded-opentype'),
		url('fonts/ast-logo.ttf?476cfz') format('truetype'),
		url('fonts/ast-logo.woff?476cfz') format('woff'),
		url('fonts/ast-logo.svg?476cfz#ast-logo') format('svg');
	font-weight: normal;
	font-style: normal;
}
#wp-admin-bar-zita .ab-icon:before,
#toplevel_page_zita .wp-menu-image:before,
[class^="ast-icon-"],
[class*=" ast-icon-"] {
	/* use !important to prevent issues with browser extensions that change fonts */
	font-family: 'ast-logo' !important;
	speak: none;
	font-style: normal;
	font-weight: normal;
	font-variant: normal;
	text-transform: none;
	line-height: 1;

	/* Better Font Rendering =========== */
	-webkit-font-smoothing: antialiased;
	-moz-osx-font-smoothing: grayscale;
}
.appearance_page_zita #wpcontent {
    padding: 0;
}
#wp-admin-bar-zita .ab-icon:before,
#toplevel_page_zita .wp-menu-image:before,
.ast-icon-logo:before {
	content: "\e900" !important;
}

#side-sortables #zita_settings_meta_box select {
	min-width: 100%;
}

#normal-sortables #zita_settings_meta_box select {
	min-width: 200px;
}

.customize-control {
	position: relative;
}

.customize-control .ast-control-tooltip {
    position: absolute;
    top: 6px;
    right: 0;
}
.customize-control.customize-control-ast-divider .ast-control-tooltip {
    position: absolute;
    top: auto;
    bottom: 3px;
    right: 0;
}
.zita-review-notice-container {
	display: flex;
	align-items: center;
	padding-top: 10px;
}

.zita-review-notice-container .dashicons {
    font-size: 1.4em;
	padding-left: 10px;
}

.zita-review-notice-container a {
    padding-left: 5px;
    text-decoration: none;
}

.zita-review-notice-container .dashicons:first-child {
    padding-left: 0;
}

.notice-image img {
    max-width: 90px;
}

.notice-content .notice-heading {
    padding-bottom: 5px;
}

.notice-content {
    margin-left: 15px;
}

.notice-container {
    padding-top: 10px;
    padding-bottom: 10px;
    display: flex;
    justify-content: left;
    align-items: center;
}

.zta-container.zta-welcome, .general .zta-container {
max-width: 900px;
}
 .zta-welcome #post-body.columns-2 #postbox-container-1 {
    float:left;
    margin-right:0;
    width:100%;
}
 .zta-welcome #poststuff #post-body.columns-2 {
    margin-right:0;
}

 .zta-welcome #poststuff #post-body.columns-2 #side-sortables {
width:100%;

}
.zta-welcome #side-sortables .postbox{
width:49%;
float:left;
border: none;
}
.zta-welcome #side-sortables .postbox:nth-child(1){
margin-right:2%;
}
.notice.zita-notice{border-left: 4px solid #f7a53e; position: relative;}
