<!-- wp:template-part {"slug":"header","tagName":"header"} /-->

<!-- wp:group {"tagName":"main","className":"site-content 404"} -->
<main id="primary" class="wp-block-group site-content 404">

	<!-- wp:group {"layout":{"inherit":true}} -->
	<div class="wp-block-group">
		<!-- wp:heading {"level":1,"textAlign":"center"} -->
		<h1 class="has-text-align-center">Page not found</h1>
		<!-- /wp:heading -->
	</div>
	<!-- /wp:group -->

	<!-- wp:group {"layout":{"inherit":true},"style":{"spacing":{"padding":{"top":"90px","right":"0px","bottom":"120px","left":"0px"}}}} -->
	<div class="wp-block-group" style="padding-top:90px;padding-right:0px;padding-bottom:120px;padding-left:0px">

		<!-- wp:paragraph -->
		<p>The page you are looking for does not exist or may have been moved/renamed. Please try a search.</p>
		<!-- /wp:paragraph -->

		<!-- wp:search {"label":"Search","showLabel":false,"placeholder":"Search...","width":300,"buttonText":"Search","buttonPosition":"button-inside","buttonUseIcon":true} /-->

	</div>
	<!-- /wp:group -->

</main>
<!-- /wp:group -->

<!-- wp:template-part {"slug":"footer","tagName":"footer"} /-->