#wp-empty-template-alert {
    display: flex;
    padding: var(--wp--style--root--padding-right, 2rem);
    min-height: 60vh;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    gap: var(--wp--style--block-gap, 2rem);
}

#wp-empty-template-alert > * {
     max-width: 400px;
}

#wp-empty-template-alert h2,
#wp-empty-template-alert p {
    margin: 0;
    text-align: center;
}

#wp-empty-template-alert a {
    margin-top: 1rem;
}
