@import '../../../../scss/mixins';

.modalInner {
  width: 1200px;
  max-width: 90vw;
  min-height: 200px;
  height: 80vh;
  display: flex;
  flex-direction: column;
  color: $textColorLight;

  p {
    @include copy;

    > a {
      color: $textColorLight;
      text-decoration: underline;
    }
  }
}

.modalHeader {
  align-items: center;
  background-color: #26292c;
  display: flex;
  flex-direction: row;
  padding: 0 13px;
}

$leftRightGutter: 80px;

.modalLogo {
  flex: 0 0 $leftRightGutter;
}

.headerNav {
  color: #fff;
  display: flex;
  flex-direction: row;
  font-size: 15px;
  justify-content: center;
  margin: auto;
  text-align: center;
  width: 50%;
}

.menuLink {
  display: flex;
  align-items: center;
  text-align: center;
  justify-content: center;
  font-size: 13px;
  text-decoration: none;
  color: #fff;
  height: 55px;
  padding: 0 30px;
  cursor: pointer;

  &:hover {
    color: #222;
    background: #f0f2f4;
  }

  &:active,
  &:focus {

    outline: 0;
    border: 0;
    box-shadow: none;
  }
}

.menuLinkActive,
.menuLinkActive:active,
.menuLinkActive:focus {
  background-color: #f0f2f4;
  box-shadow: inset 0 -1px 0 0 #81b440;
  color: #555d66;

  .subNavWrap & {
    box-shadow: none;
  }
}

.headerActions {
  display: flex;
  justify-content: flex-end;
  flex-direction: row;
  flex: 0 0 $leftRightGutter;
}

.closeButton {
  cursor: pointer;
  color: #919191;
  border: 0;
  background: transparent;
  margin-left: 12px;
  padding-right: 6px;
  display: flex;

  [dir='rtl'] & {
    margin-left: 0;
    margin-right: 12px;
  }

  &::before {
    content: '';
    display: inline-block;
    border-left: 1px solid #a5afb7;
    color: #fff;
    margin-right: 10px;
    height: 20px;
    opacity: 0.3;

    [dir='rtl'] & {
      margin-right: 0;
      margin-left: 10px;
    }
  }
}

.dismissIcon {
  @include dismiss;
}

.magicInner {
  overflow-y: auto;
}
