.wp-block-navigation .block-list-appender{
  position:relative;
}
.wp-block-navigation .has-child{
  cursor:pointer;
}
.wp-block-navigation .has-child .wp-block-navigation__submenu-container{
  z-index:28;
}
.wp-block-navigation .has-child:hover .wp-block-navigation__submenu-container{
  z-index:29;
}
.wp-block-navigation .has-child.has-child-selected>.wp-block-navigation__submenu-container,.wp-block-navigation .has-child.is-selected>.wp-block-navigation__submenu-container{
  height:auto !important;
  min-width:200px !important;
  opacity:1 !important;
  overflow:visible !important;
  visibility:visible !important;
  width:auto !important;
}
.wp-block-navigation-item .wp-block-navigation-item__content{
  cursor:text;
}
.wp-block-navigation-item.is-editing,.wp-block-navigation-item.is-selected{
  min-width:20px;
}
.wp-block-navigation-item .block-list-appender{
  margin:16px 16px 16px auto;
}

.wp-block-navigation-link__invalid-item{
  color:#000;
}
.wp-block-navigation-link__placeholder{
  background-image:none !important;
  box-shadow:none !important;
  position:relative;
  text-decoration:none !important;
}
.wp-block-navigation-link__placeholder .wp-block-navigation-link__placeholder-text span{
  -webkit-text-decoration:wavy underline;
          text-decoration:wavy underline;
  -webkit-text-decoration-skip-ink:none;
          text-decoration-skip-ink:none;
  text-underline-offset:.25rem;
}
.wp-block-navigation-link__placeholder.wp-block-navigation-item__content{
  cursor:pointer;
}
.link-control-transform{
  border-top:1px solid #ccc;
  padding:0 16px 8px;
}

.link-control-transform__subheading{
  color:#1e1e1e;
  font-size:11px;
  font-weight:500;
  margin-bottom:1.5em;
  text-transform:uppercase;
}

.link-control-transform__items{
  display:flex;
  justify-content:space-between;
}

.link-control-transform__item{
  flex-basis:33%;
  flex-direction:column;
  gap:8px;
  height:auto;
}

.link-ui-page-creator{
  max-width:350px;
  min-width:auto;
  padding-top:8px;
  width:90vw;
}
.link-ui-page-creator__inner{
  padding:16px;
}
.link-ui-page-creator__back{
  margin-right:8px;
  text-transform:uppercase;
}
.navigation-link-control__error-text{
  color:#cc1818;
}