<?php
return array(
			'title'         => __( 'Team 2', 'alara' ),
			'categories'    => array( 'alara-about' ),
			'keywords'		=> array( 'about', 'info', 'media', 'image' ),
			'viewportWidth' => 1440,
			'content'       => '<!-- wp:heading {"textAlign":"center"} -->
<h2 class="has-text-align-center" id="meet-the-team">Meet the Team</h2>
<!-- /wp:heading -->

<!-- wp:separator {"color":"primary"} -->
<hr class="wp-block-separator has-text-color has-background has-primary-background-color has-primary-color"/>
<!-- /wp:separator -->

<!-- wp:spacer {"height":9} -->
<div style="height:9px" aria-hidden="true" class="wp-block-spacer"></div>
<!-- /wp:spacer -->

<!-- wp:columns -->
<div class="wp-block-columns"><!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"linkDestination":"none","style":{"color":{"duotone":["#000000","#ffffff"]}},"className":"is-style-rounded"} -->
<figure class="wp-block-image is-style-rounded"><img src="' . alara_pattern_content( 'image-man-3' ) . '" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"align":"center","className":"is-style-script"} -->
<p class="has-text-align-center is-style-script">Alex Kamal</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">Design</p>
<!-- /wp:paragraph -->

<!-- wp:social-links {"iconColor":"foreground","iconColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dforeground)","iconBackgroundColor":"background","iconBackgroundColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dbackground)","size":"has-normal-icon-size","layout":{"type":"flex","justifyContent":"center"},"style":{"spacing":{"blockGap":"7px"}}} -->
<ul class="wp-block-social-links has-normal-icon-size has-icon-color has-icon-background-color">' . alara_pattern_content( 'social-media' ) . '</ul>
<!-- /wp:social-links --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"linkDestination":"none","style":{"color":{"duotone":["#000000","#ffffff"]}},"className":"is-style-rounded"} -->
<figure class="wp-block-image is-style-rounded"><img src="' . alara_pattern_content( 'image-woman-1' ) . '" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"align":"center","className":"is-style-script"} -->
<p class="has-text-align-center is-style-script">Naomi Nagata</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">Development</p>
<!-- /wp:paragraph -->

<!-- wp:social-links {"iconColor":"foreground","iconColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dforeground)","iconBackgroundColor":"background","iconBackgroundColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dbackground)","size":"has-normal-icon-size","layout":{"type":"flex","justifyContent":"center"},"style":{"spacing":{"blockGap":"7px"}}} -->
<ul class="wp-block-social-links has-normal-icon-size has-icon-color has-icon-background-color">' . alara_pattern_content( 'social-media' ) . '</ul>
<!-- /wp:social-links --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"linkDestination":"none","style":{"color":{"duotone":["#000000","#ffffff"]}},"className":"is-style-rounded"} -->
<figure class="wp-block-image is-style-rounded"><img src="' . alara_pattern_content( 'image-man-2' ) . '" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"align":"center","className":"is-style-script"} -->
<p class="has-text-align-center is-style-script">Amos Burton</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">Support</p>
<!-- /wp:paragraph -->

<!-- wp:social-links {"iconColor":"foreground","iconColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dforeground)","iconBackgroundColor":"background","iconBackgroundColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dbackground)","size":"has-normal-icon-size","layout":{"type":"flex","justifyContent":"center"},"style":{"spacing":{"blockGap":"7px"}}} -->
<ul class="wp-block-social-links has-normal-icon-size has-icon-color has-icon-background-color">' . alara_pattern_content( 'social-media' ) . '</ul>
<!-- /wp:social-links --></div>
<!-- /wp:column -->

<!-- wp:column -->
<div class="wp-block-column"><!-- wp:image {"linkDestination":"none","style":{"color":{"duotone":["#000000","#ffffff"]}},"className":"is-style-rounded"} -->
<figure class="wp-block-image is-style-rounded"><img src="' . alara_pattern_content( 'image-man-1' ) . '" alt=""/></figure>
<!-- /wp:image -->

<!-- wp:paragraph {"align":"center","className":"is-style-script"} -->
<p class="has-text-align-center is-style-script">James Holden</p>
<!-- /wp:paragraph -->

<!-- wp:paragraph {"align":"center"} -->
<p class="has-text-align-center">Sales</p>
<!-- /wp:paragraph -->

<!-- wp:social-links {"iconColor":"foreground","iconColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dforeground)","iconBackgroundColor":"background","iconBackgroundColorValue":"var(\u002d\u002dwp\u002d\u002dpreset\u002d\u002dcolor\u002d\u002dbackground)","size":"has-normal-icon-size","layout":{"type":"flex","justifyContent":"center"},"style":{"spacing":{"blockGap":"7px"}}} -->
<ul class="wp-block-social-links has-normal-icon-size has-icon-color has-icon-background-color">' . alara_pattern_content( 'social-media' ) . '</ul>
<!-- /wp:social-links --></div>
<!-- /wp:column --></div>
<!-- /wp:columns -->',
);
