.wp-block-comment-template{
  box-sizing:border-box;
  list-style:none;
  margin-bottom:0;
  max-width:100%;
  padding:0;
}
.wp-block-comment-template li{
  clear:both;
}
.wp-block-comment-template ol{
  list-style:none;
  margin-bottom:0;
  max-width:100%;
  padding-right:2rem;
}
.wp-block-comment-template.alignleft{
  float:right;
}
.wp-block-comment-template.aligncenter{
  margin-left:auto;
  margin-right:auto;
  width:fit-content;
}
.wp-block-comment-template.alignright{
  float:left;
}