/*! elementor - v3.5.6 - 28-02-2022 */
#e-dashboard-widget-admin-top-bar {
  position: absolute;
  opacity: 0;
  pointer-events: none; }

#e-admin-top-bar-root {
  right: 0;
  background: #ffffff;
  -webkit-box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.0394871);
          box-shadow: 0px 4px 6px rgba(0, 0, 0, 0.0394871);
  display: none;
  position: absolute;
  top: 0;
  width: calc(100% - 160px);
  z-index: 1; }
  #e-admin-top-bar-root .e-admin-top-bar {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    height: 50px;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between;
    padding: 0 16px; }
  #e-admin-top-bar-root .page-title-action {
    background: #f7f7f7;
    border: 1px solid #0275d8;
    -webkit-border-radius: 3px;
            border-radius: 3px;
    -webkit-box-sizing: border-box;
            box-sizing: border-box;
    color: #0275d8;
    cursor: pointer;
    display: inline-block;
    line-height: 30px;
    margin: 0 4px;
    min-height: 30px;
    padding: 0 10px;
    text-decoration: none; }
    #e-admin-top-bar-root .page-title-action:hover {
      background: #eceeef;
      border-color: #1b607f;
      color: #1b607f; }
  #e-admin-top-bar-root .e-admin-top-bar__heading {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    -webkit-margin-end: 40px;
            margin-inline-end: 40px; }
  #e-admin-top-bar-root .e-admin-top-bar__main-area {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
    #e-admin-top-bar-root .e-admin-top-bar__main-area button {
      margin: 0 4px; }
  #e-admin-top-bar-root .e-admin-top-bar__secondary-area {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
  #e-admin-top-bar-root .e-admin-top-bar__heading-logo {
    width: 30px; }
  #e-admin-top-bar-root .e-admin-top-bar__heading-logo {
    background: #93003c;
    -webkit-border-radius: 15px;
            border-radius: 15px;
    color: #ffffff;
    display: inline-block;
    font-size: 0.875rem;
    height: 1.875rem;
    line-height: 1.875rem;
    text-align: center;
    width: 1.875rem; }
  #e-admin-top-bar-root .e-admin-top-bar__heading-title {
    color: #495157;
    font-size: 15px;
    font-weight: 700;
    font-family: 'Roboto', Arial, Helvetica, Verdana, sans-serif;
    padding: 0 8px;
    line-height: normal;
    text-transform: uppercase; }
  #e-admin-top-bar-root.e-admin-top-bar--active {
    display: block; }
    #e-admin-top-bar-root.e-admin-top-bar--active ~ #wpbody #wpbody-content {
      margin-top: 50px; }
    #e-admin-top-bar-root.e-admin-top-bar--active ~ #wpbody .wrap {
      clear: both;
      padding-top: 10px; }
      #e-admin-top-bar-root.e-admin-top-bar--active ~ #wpbody .wrap h1 {
        display: none; }
  #e-admin-top-bar-root:not(.e-admin-top-bar--active) ~ #wpbody .wrap h1, #e-admin-top-bar-root:not(.e-admin-top-bar--active) ~ #wpbody .wrap .page-title-action {
    display: inline-block; }
  #e-admin-top-bar-root .e-admin-top-bar__bar-button {
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    cursor: pointer;
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center;
    margin: 0 10px;
    text-decoration: none;
    color: #6d7882; }
    #e-admin-top-bar-root .e-admin-top-bar__bar-button .e-admin-top-bar__bar-button-title {
      color: #6d7882; }
    #e-admin-top-bar-root .e-admin-top-bar__bar-button .e-admin-top-bar__bar-button-icon {
      margin: 0 4px; }
    #e-admin-top-bar-root .e-admin-top-bar__bar-button:hover .e-admin-top-bar__bar-button-title,
    #e-admin-top-bar-root .e-admin-top-bar__bar-button:hover .e-admin-top-bar__bar-button-icon {
      color: #93003c; }
  #e-admin-top-bar-root .e-admin-top-bar__bar-button-title {
    font-size: 13px;
    font-weight: 500;
    font-family: Roboto, Arial, Helvetica, Verdana, sans-serif;
    margin: 0 4px;
    line-height: normal; }
  #e-admin-top-bar-root ~ #wpbody .wrap h1, #e-admin-top-bar-root ~ #wpbody .wrap .page-title-action {
    display: none; }

@media screen and (max-width: 960px) {
  #e-admin-top-bar-root {
    width: calc(100% - 36px); } }

@media screen and (max-width: 782px) {
  #e-admin-top-bar-root {
    width: 100%; } }

@media screen and (max-width: 600px) {
  #e-admin-top-bar-root {
    top: 46px; } }

@media (max-width: 768px) {
  #e-admin-top-bar-root {
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
    #e-admin-top-bar-root .e-admin-top-bar__main-area-buttons {
      position: absolute;
      top: calc(100% + 10px); }
    #e-admin-top-bar-root .e-admin-top-bar__secondary-area .e-admin-top-bar__secondary-area-buttons {
      display: none; }
    #e-admin-top-bar-root .e-admin-top-bar__secondary-area > .e-admin-top-bar__bar-button .e-admin-top-bar__bar-button-title {
      display: none; } }

@media (min-width: 768px) {
  #e-admin-top-bar-root .e-admin-top-bar__secondary-area .e-admin-top-bar__secondary-area-buttons {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; } }
/*# sourceMappingURL=admin-top-bar.css.map */